% Auto-generated chapter 24 for ibnmajah
% Hadiths in this chapter: 129

\hadithdefcmd{ibnmajah}{2753}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ فُضَيْلٍ، عَنْ عُمَارَةَ بْنِ الْقَعْقَاعِ، عَنْ أَبِي زُرْعَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ أَعَدَّ اللَّهُ لِمَنْ خَرَجَ فِي سَبِيلِهِ لاَ يُخْرِجُهُ إِلاَّ جِهَادٌ فِي سَبِيلِي وَإِيمَانٌ بِي وَتَصْدِيقٌ بِرُسُلِي فَهُوَ عَلَىَّ ضَامِنٌ أَنْ أُدْخِلَهُ الْجَنَّةَ أَوْ أَرْجِعَهُ إِلَى مَسْكَنِهِ الَّذِي خَرَجَ مِنْهُ نَائِلاً مَا نَالَ مِنْ أَجْرٍ أَوْ غَنِيمَةٍ ‏"‏ ‏.‏ ثُمَّ قَالَ ‏"‏ وَالَّذِي نَفْسِي بِيَدِهِ لَوْلاَ أَنْ أَشُقَّ عَلَى الْمُسْلِمِينَ مَا قَعَدْتُ خِلاَفَ سَرِيَّةٍ تَخْرُجُ فِي سَبِيلِ اللَّهِ أَبَدًا وَلَكِنْ لاَ أَجِدُ سَعَةً فَأَحْمِلَهُمْ وَلاَ يَجِدُونَ سَعَةً فَيَتَّبِعُونِي وَلاَ تَطِيبُ أَنْفُسُهُمْ فَيَتَخَلَّفُونَ بَعْدِي وَالَّذِي نَفْسُ مُحَمَّدٍ بِيَدِهِ لَوَدِدْتُ أَنْ أَغْزُوَ فِي سَبِيلِ اللَّهِ فَأُقْتَلَ ثُمَّ أَغْزُوَ فَأُقْتَلَ ثُمَّ أَغْزُوَ فَأُقْتَلَ ‏"‏ ‏.‏\hadithno{2753}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Allah has prepared (reward) for those who go out (to fight) in His cause: ‘And do not go out except (to fight) for Jihad in My cause, out of faith in Me and belief in My Messengers, but he has a guarantee from Me that I will admit him to Paradise, or I will return him to his dwelling from which he set out, with the reward that he attained, or the spoils that he acquired.’ Then he said: ‘By the One in Whose Hand is my soul, were it not that it would be too difficult for the Muslims, I would never have stayed behind from any expedition that went out in the cause of Allah. But I could not find the resources to give them mounts and they could not find the resources to follow me, nor would they be pleased to stay behind if I went. By the One in Whose Hand is the soul of Muhammad, I wish I could fight in the cause of Allah and be killed, then fight and be killed, then fight and be killed.’”}}
\hadithdefcmd{ibnmajah}{2754}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَأَبُو كُرَيْبٍ قَالاَ حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ شَيْبَانَ، عَنْ فِرَاسٍ، عَنْ عَطِيَّةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ الْمُجَاهِدُ فِي سَبِيلِ اللَّهِ مَضْمُونٌ عَلَى اللَّهِ إِمَّا أَنْ يَكْفِتَهُ إِلَى مَغْفِرَتِهِ وَرَحْمَتِهِ وَإِمَّا أَنْ يَرْجِعَهُ بِأَجْرٍ وَغَنِيمَةٍ وَمَثَلُ الْمُجَاهِدِ فِي سَبِيلِ اللَّهِ كَمَثَلِ الصَّائِمِ الْقَائِمِ الَّذِي لاَ يَفْتُرُ حَتَّى يَرْجِعَ ‏"‏ ‏.‏\hadithno{2754}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Prophet (ﷺ) said:“The one who fights in the cause of Allah has a guarantee from Allah. Either He will raise him to His forgiveness and mercy, or He will send him back with reward and spoils of war. The likeness of the one who fights in the cause of Allah is that of one who fasts and prays at night without ceasing, until he returns.”}}
\hadithdefcmd{ibnmajah}{2755}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَبْدُ اللَّهِ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَدْوَةٌ أَوْ رَوْحَةٌ فِي سَبِيلِ اللَّهِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏\hadithno{2755}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Going out in the morning in the cause of Allah, or in the evening, is more virtuous than the world and what is in it.”}}
\hadithdefcmd{ibnmajah}{2756}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا زَكَرِيَّا بْنُ مَنْظُورٍ، حَدَّثَنَا أَبُو حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَدْوَةٌ أَوْ رَوْحَةٌ فِي سَبِيلِ اللَّهِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏\hadithno{2756}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Sahl bin Sa’d As-Sa’idi that the Messenger of Allah (ﷺ) said:“Going out in the morning in the cause of Allah, or in the evening, is better than the world and what is in it.”}}
\hadithdefcmd{ibnmajah}{2757}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، وَمُحَمَّدُ بْنُ الْمُثَنَّى، قَالاَ حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، حَدَّثَنَا حُمَيْدٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَغَدْوَةٌ أَوْ رَوْحَةٌ فِي سَبِيلِ اللَّهِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏\hadithno{2757}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“Going out in the morning in the cause of Allah, or in the evening, is better than the world and what is in it.”}}
\hadithdefcmd{ibnmajah}{2758}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يُونُسُ بْنُ مُحَمَّدٍ، حَدَّثَنَا لَيْثُ بْنُ سَعْدٍ، عَنْ يَزِيدَ بْنِ عَبْدِ اللَّهِ بْنِ الْهَادِ، عَنِ الْوَلِيدِ بْنِ أَبِي الْوَلِيدِ، عَنْ عُثْمَانَ بْنِ عَبْدِ اللَّهِ بْنِ سُرَاقَةَ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ جَهَّزَ غَازِيًا فِي سَبِيلِ اللَّهِ حَتَّى يَسْتَقِلَّ كَانَ لَهُ مِثْلُ أَجْرِهِ حَتَّى يَمُوتَ أَوْ يَرْجِعَ ‏"‏ ‏.‏\hadithno{2758}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Umar bin Khattab said:“I heard the Messenger of Allah (ﷺ) say: ‘Whoever equips a warrior in the cause of Allah until he is fully equipped, he will have a reward like his, until he dies or returns.”}}
\hadithdefcmd{ibnmajah}{2759}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ عَبْدِ الْمَلِكِ بْنِ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ جَهَّزَ غَازِيًا فِي سَبِيلِ اللَّهِ كَانَ لَهُ مِثْلُ أَجْرِهِ مِنْ غَيْرِ أَنْ يَنْقُصَ مِنْ أَجْرِ الْغَازِي شَيْئًا ‏"‏ ‏.‏\hadithno{2759}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Zaid bin Khalid Al-Juhani that the Messenger of Allah (ﷺ) said:“Whoever equips a warrior in the cause of Allah, he will have a reward like his, without that detracting from the warrior’s reward in the slightest.”}}
\hadithdefcmd{ibnmajah}{2760}{حَدَّثَنَا عِمْرَانُ بْنُ مُوسَى اللَّيْثِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، حَدَّثَنَا أَيُّوبُ، عَنْ أَبِي قِلاَبَةَ، عَنْ أَبِي أَسْمَاءَ، عَنْ ثَوْبَانَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَفْضَلُ دِينَارٍ يُنْفِقُهُ الرَّجُلُ دِينَارٌ يُنْفِقُهُ عَلَى عِيَالِهِ وَدِينَارٌ يُنْفِقُهُ عَلَى فَرَسٍ فِي سَبِيلِ اللَّهِ وَدِينَارٌ يُنْفِقُهُ الرَّجُلُ عَلَى أَصْحَابِهِ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏\hadithno{2760}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Thawban that the Messenger of Allah (ﷺ) said:“The best Dinar that a man can spend is a Dinar that he spends on his family, a Dinar that he spends on a horse in the cause of Allah, and a Dinar that a man spends on his companions in the cause of Allah.”}}
\hadithdefcmd{ibnmajah}{2761}{حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ الْحَمَّالُ، حَدَّثَنَا ابْنُ أَبِي فُدَيْكٍ، عَنِ الْخَلِيلِ بْنِ عَبْدِ اللَّهِ، عَنِ الْحَسَنِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، وَأَبِي الدَّرْدَاءِ، وَأَبِي، هُرَيْرَةَ وَأَبِي أُمَامَةَ الْبَاهِلِيِّ وَعَبْدِ اللَّهِ بْنِ عُمَرَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَجَابِرِ بْنِ عَبْدِ اللَّهِ وَعِمْرَانَ بْنِ الْحُصَيْنِ كُلُّهُمْ يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ مَنْ أَرْسَلَ بِنَفَقَةٍ فِي سَبِيلِ اللَّهِ وَأَقَامَ فِي بَيْتِهِ فَلَهُ بِكُلِّ دِرْهَمٍ سَبْعُمِائَةِ دِرْهَمٍ وَمَنْ غَزَا بِنَفْسِهِ فِي سَبِيلِ اللَّهِ وَأَنْفَقَ فِي وَجْهِ ذَلِكَ فَلَهُ بِكُلِّ دِرْهَمٍ سَبْعُمِائَةِ أَلْفِ دِرْهَمٍ ‏"‏ ‏.‏ ثُمَّ تَلاَ هَذِهِ الآيَةَ ‏\{وَاللَّهُ يُضَاعِفُ لِمَنْ يَشَاءُ\}‏ ‏.‏\hadithno{2761}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Ali bin Abu Talib, Abu Darda’, Abu Hurairah, Abu Umamah Al-Bahili, ‘Abdullah bin ‘Umar, ‘Abdullah bin ‘Amr, Jabir bin ‘Abdullah and ‘Imran bin Husain, all of them narrating that the Messenger of Allah (ﷺ) said:“Whoever sends financial support in the cause of Allah and stays at home, for every Dirham he will have (the reward of) seven hundred Dirham. Whoever fights himself in the cause of Allah, and spends on that, for every Dirham he will have (the reward of) seven hundred thousand Dirham.” Then he recited the Verse: “Allah gives manifold increase to whom He wills.”[2:]}}
\hadithdefcmd{ibnmajah}{2762}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا يَحْيَى بْنُ الْحَارِثِ الذِّمَارِيُّ، عَنِ الْقَاسِمِ، عَنْ أَبِي أُمَامَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ لَمْ يَغْزُ أَوْ يُجَهِّزْ غَازِيًا أَوْ يَخْلُفْ غَازِيًا فِي أَهْلِهِ بِخَيْرٍ أَصَابَهُ اللَّهُ سُبْحَانَهُ بِقَارِعَةٍ قَبْلَ يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2762}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Umamah that the Prophet (ﷺ) said:“Whoever does not fight, or equip a fighter, or stay behind to look after a fighter’s family, Allah will strike him with a calamity before the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{2763}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنَا أَبُو رَافِعٍ، - هُوَ إِسْمَاعِيلُ بْنُ رَافِعٍ - عَنْ سُمَىٍّ، - مَوْلَى أَبِي بَكْرٍ - عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لَقِيَ اللَّهَ وَلَيْسَ لَهُ أَثَرٌ فِي سَبِيلِ اللَّهِ لَقِيَ اللَّهَ وَفِيهِ ثُلْمَةٌ ‏"‏ ‏.‏\hadithno{2763}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever meets Allah with no mark on him (as a result of fighting) in His cause, he will meet Him with a deficiency.”}}
\hadithdefcmd{ibnmajah}{2764}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ حُمَيْدٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ لَمَّا رَجَعَ رَسُولُ اللَّهِ صلى الله عليه وسلم مِنْ غَزْوَةِ تَبُوكَ فَدَنَا مِنَ الْمَدِينَةِ قَالَ ‏"‏ إِنَّ بِالْمَدِينَةِ لَقَوْمًا مَا سِرْتُمْ مِنْ مَسِيرٍ وَلاَ قَطَعْتُمْ وَادِيًا إِلاَّ كَانُوا مَعَكُمْ فِيهِ ‏"‏ ‏.‏ قَالُوا يَا رَسُولَ اللَّهِ وَهُمْ بِالْمَدِينَةِ قَالَ ‏"‏ وَهُمْ بِالْمَدِينَةِ حَبَسَهُمُ الْعُذْرُ ‏"‏ ‏.‏\hadithno{2764}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Anas bin Malik said:“When the Messenger of Allah (ﷺ) was returning from the campaign of Tabuk, and had drawn close to Al-Madinah, he said: ‘In Al-Madinah there are people who, as you traveled and crossed valleys, were with you.’ They said: ‘O Messenger of Allah, even though they are in Al-Madinah?’ He said: ‘Even though they were in Al-Madinah. They were kept behind by (legitimate) excuses.’”}}
\hadithdefcmd{ibnmajah}{2765}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي سُفْيَانَ، عَنْ جَابِرٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ بِالْمَدِينَةِ رِجَالاً مَا قَطَعْتُمْ وَادِيًا وَلاَ سَلَكْتُمْ طَرِيقًا إِلاَّ شَرِكُوكُمْ فِي الأَجْرِ حَبَسَهُمُ الْعُذْرُ ‏"‏ ‏.‏ قَالَ أَبُو عَبْدِ اللَّهِ بْنُ مَاجَهْ أَوْ كَمَا قَالَ كَتَبْتُهُ لَفْظًا ‏.‏\hadithno{2765}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Jabir that the Messenger of Allah (ﷺ) said:“in Al-Madinah there are men who, every time you crossed a valley or travelled a road, they shared with you in the reward. They were kept behind by (legitimate) excuses.”}}
\hadithdefcmd{ibnmajah}{2766}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ زَيْدِ بْنِ أَسْلَمَ، عَنْ أَبِيهِ، عَنْ مُصْعَبِ بْنِ ثَابِتٍ، عَنْ عَبْدِ اللَّهِ بْنِ الزُّبَيْرِ، قَالَ خَطَبَ عُثْمَانُ بْنُ عَفَّانَ النَّاسَ فَقَالَ يَا أَيُّهَا النَّاسُ إِنِّي سَمِعْتُ حَدِيثًا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم لَمْ يَمْنَعْنِي أَنْ أُحَدِّثَكُمْ بِهِ إِلاَّ الضِّنُّ بِكُمْ وَبِصَحَابَتِكُمْ فَلْيَخْتَرْ مُخْتَارٌ لِنَفْسِهِ أَوْ لِيَدَعْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ رَابَطَ لَيْلَةً فِي سَبِيلِ اللَّهِ سُبْحَانَهُ كَانَتْ كَأَلْفِ لَيْلَةٍ صِيَامِهَا وَقِيَامِهَا ‏"‏ ‏.‏\hadithno{2766}\hadithgrade{Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Abdullah bin Zubair said:“Uthman bin ‘Affan addressed the people and said: ‘O people! I heard a Hadith from the Messenger of Allah (ﷺ) and nothing kept me from narrating it to you except for the fact that I did not want to lose you and your companionship. So it is up to you. I heard the Messenger of Allah (ﷺ) saying: “Whoever spends a night guarding the frontier in the cause of Allah, it will be like a thousand nights spent in fasting and prayer.”}}
\hadithdefcmd{ibnmajah}{2767}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي اللَّيْثُ، عَنْ زُهْرَةَ بْنِ مَعْبَدٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ مَاتَ مُرَابِطًا فِي سَبِيلِ اللَّهِ أَجْرَى عَلَيْهِ أَجْرَ عَمَلِهِ الصَّالِحِ الَّذِي كَانَ يَعْمَلُ وَأَجْرَى عَلَيْهِ رِزْقَهُ وَأَمِنَ مِنَ الْفَتَّانِ وَبَعَثَهُ اللَّهُ يَوْمَ الْقِيَامَةِ آمِنًا مِنَ الْفَزَعِ ‏"‏ ‏.‏\hadithno{2767}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever dies being prepared in the cause of Allah, will be given continuously the reward for the good deeds that he used to do, and he will be rewarded with provision, and he will be kept safe from Fattan,* and Allah will raise him on the Day of Resurrection free of fright.”}}
\hadithdefcmd{ibnmajah}{2768}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ سَمُرَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ يَعْلَى السُّلَمِيُّ، حَدَّثَنَا عُمَرُ بْنُ صُبْحٍ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَمْرٍو، عَنْ مَكْحُولٍ، عَنْ أُبَىِّ بْنِ كَعْبٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَرِبَاطُ يَوْمٍ فِي سَبِيلِ اللَّهِ مِنْ وَرَاءِ عَوْرَةِ الْمُسْلِمِينَ مُحْتَسِبًا مِنْ غَيْرِ شَهْرِ رَمَضَانَ أَعْظَمُ أَجْرًا مِنْ عِبَادَةِ مِائَةِ سَنَةٍ صِيَامِهَا وَقِيَامِهَا وَرِبَاطُ يَوْمٍ فِي سَبِيلِ اللَّهِ مِنْ وَرَاءِ عَوْرَةِ الْمُسْلِمِينَ مُحْتَسِبًا مِنْ شَهْرِ رَمَضَانَ أَفْضَلُ عِنْدَ اللَّهِ وَأَعْظَمُ أَجْرًا - أُرَاهُ قَالَ - مِنْ عِبَادَةِ أَلْفِ سَنَةٍ صِيَامِهَا وَقِيَامِهَا فَإِنْ رَدَّهُ اللَّهُ إِلَى أَهْلِهِ سَالِمًا لَمْ تُكْتَبْ عَلَيْهِ سَيِّئَةٌ أَلْفَ سَنَةٍ وَتُكْتَبُ لَهُ الْحَسَنَاتُ وَيُجْرَى لَهُ أَجْرُ الرِّبَاطِ إِلَى يَوْمِ الْقِيَامَةَ ‏"‏ ‏.‏\hadithno{2768}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Ubayy bin Ka’b said:“The Messenger of Allah (ﷺ) said: ‘For guarding the frontier for a day in the cause of Allah, defending the Muslims, seeking reward, apart from in the month of Ramadan, there is a reward granted greater than worshipping for a hundred years, fasting and praying. Guarding the frontier for a day in the cause of Allah, defending the Muslims, seeking reward, in the month of Ramadan, is better before Allah and brings a greater reward” – I think he said – “than worshipping for a thousand years, fasting and praying. If Allah returns him to his family safe and sound, no bad deed will be recorded for him for a thousand years, but his good deeds will be recorded, and the reward for guarding the frontier will come to him until the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{2769}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ صَالِحِ بْنِ مُحَمَّدِ بْنِ زَائِدَةَ، عَنْ عُمَرَ بْنِ عَبْدِ الْعَزِيزِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ رَحِمَ اللَّهُ حَارِسَ الْحَرَسِ ‏"‏ ‏.‏\hadithno{2769}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from ‘Uqbah bin ‘Amir Al-Juhani that the Messenger of Allah (ﷺ) said:“May Allah have mercy on the one who keeps watch over the troops.”}}
\hadithdefcmd{ibnmajah}{2770}{حَدَّثَنَا عِيسَى بْنُ يُونُسَ الرَّمْلِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ شُعَيْبِ بْنِ شَابُورَ، عَنْ سَعِيدِ بْنِ خَالِدِ بْنِ أَبِي الطَّوِيلِ، قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ حَرْسُ لَيْلَةٍ فِي سَبِيلِ اللَّهِ أَفْضَلُ مِنْ صِيَامِ رَجُلٍ وَقِيَامِهِ فِي أَهْلِهِ أَلْفَ سَنَةٍ السَّنَةُ ثَلاَثُمِائَةٍ وَسِتُّونَ يَوْمًا وَالْيَوْمُ كَأَلْفِ سَنَةٍ ‏"‏ ‏.‏\hadithno{2770}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sa’eed bin Khalid bin Abu Tuwail said:I heard Anas bin Malik saying: I heard the Messenger of Allah (ﷺ) say: “Standing guard one night in the cause of Allah is better than a man fasting and praying, among his family, for a thousand years. The year is three hundred and sixty days and a day is like a thousand years.”}}
\hadithdefcmd{ibnmajah}{2771}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لِرَجُلٍ ‏ "‏ أُوصِيكَ بِتَقْوَى اللَّهِ وَالتَّكْبِيرِ عَلَى كُلِّ شَرَفٍ ‏"‏ ‏.‏\hadithno{2771}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said to a man:“I advise you to fear Allah and to say the Takbir (Allahu Akbar) in every high place.”}}
\hadithdefcmd{ibnmajah}{2772}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدَةَ، أَنْبَأَنَا حَمَّادُ بْنُ زَيْدٍ، عَنْ ثَابِتٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ ذُكِرَ النَّبِيُّ صلى الله عليه وسلم فَقَالَ كَانَ أَحْسَنَ النَّاسِ وَكَانَ أَجْوَدَ النَّاسِ وَكَانَ أَشْجَعَ النَّاسِ وَلَقَدْ فَزِعَ أَهْلُ الْمَدِينَةِ لَيْلَةً فَانْطَلَقُوا قِبَلَ الصَّوْتِ فَتَلَقَّاهُمْ رَسُولُ اللَّهِ صلى الله عليه وسلم وَقَدْ سَبَقَهُمْ إِلَى الصَّوْتِ وَهُوَ عَلَى فَرَسٍ لأَبِي طَلْحَةَ عُرْىٍ مَا عَلَيْهِ سَرْجٌ فِي عُنُقِهِ السَّيْفُ وَهُوَ يَقُولُ ‏"‏ يَا أَيُّهَا النَّاسُ لَنْ تُرَاعُوا ‏"‏ ‏.‏ يَرُدُّهُمْ ثُمَّ قَالَ لِلْفَرَسِ ‏"‏ وَجَدْنَاهُ بَحْرًا ‏"‏ ‏.‏ أَوْ ‏"‏ إِنَّهُ لَبَحْرٌ ‏"‏ ‏.‏ قَالَ حَمَّادٌ وَحَدَّثَنِي ثَابِتٌ أَوْ غَيْرُهُ قَالَ كَانَ فَرَسًا لأَبِي طَلْحَةَ يُبَطَّأُ فَمَا سُبِقَ بَعْدَ ذَلِكَ الْيَوْمِ ‏.‏\hadithno{2772}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Hammad bin Zaid from Thabit, that the Prophet (ﷺ) was mentioned before Anas bin Malik and he said:“He was the best of people, the most generous of people, the most courageous of people. The people of Al-Madinah became alarmed one night, and he was the first of them to investigate the noise and din. He was riding a horse belonging to Abu Talhah, bareback, with no saddle. His sword was hanging from his neck and he was saying: ‘O people, do not be afraid,’ sending them back to their houses. Then he said of the horse, ‘We found it like a sea,’ or, ‘It is a sea.’”}}
\hadithdefcmd{ibnmajah}{2773}{حَدَّثَنَا أَحْمَدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ بَكَّارِ بْنِ عَبْدِ الْمَلِكِ بْنِ الْوَلِيدِ بْنِ بُسْرِ بْنِ أَبِي أَرْطَاةَ، حَدَّثَنَا الْوَلِيدُ، حَدَّثَنِي شَيْبَانُ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ إِذَا اسْتُنْفِرْتُمْ فَانْفِرُوا ‏"‏ ‏.‏\hadithno{2773}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) said:“If you are called to arms then go forth.”}}
\hadithdefcmd{ibnmajah}{2774}{حَدَّثَنَا يَعْقُوبُ بْنُ حُمَيْدِ بْنِ كَاسِبٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، - مَوْلَى آلِ طَلْحَةَ - عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَجْتَمِعُ غُبَارٌ فِي سَبِيلِ اللَّهِ وَدُخَانُ جَهَنَّمَ فِي جَوْفِ عَبْدٍ مُسْلِمٍ ‏"‏ ‏.‏\hadithno{2774}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“The dust (of Jihad) in the cause of Allah and the smoke of Hell will never be combined in the interior of a Muslim.”}}
\hadithdefcmd{ibnmajah}{2775}{حَدَّثَنَا مُحَمَّدُ بْنُ سَعِيدِ بْنِ يَزِيدَ بْنِ إِبْرَاهِيمَ التُّسْتَرِيُّ، حَدَّثَنَا أَبُو عَاصِمٍ، عَنْ شَبِيبٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ رَاحَ رَوْحَةً فِي سَبِيلِ اللَّهِ كَانَ لَهُ بِمِثْلِ مَا أَصَابَهُ مِنَ الْغُبَارِ مِسْكًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2775}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“Whoever goes out in the cause of Allah will have the equivalent of the dust that got on him, in musk, on the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{2776}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنِ ابْنِ حَبَّانَ، - هُوَ مُحَمَّدُ بْنُ يَحْيَى بْنِ حَبَّانَ - عَنْ أَنَسِ بْنِ مَالِكٍ، عَنْ خَالَتِهِ أُمِّ حَرَامٍ بِنْتِ مِلْحَانَ، أَنَّهَا قَالَتْ نَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا قَرِيبًا مِنِّي ثُمَّ اسْتَيْقَظَ يَبْتَسِمُ فَقُلْتُ يَا رَسُولَ اللَّهِ مَا أَضْحَكَكَ قَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ يَرْكَبُونَ ظَهْرَ هَذَا الْبَحْرِ كَالْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏ ‏.‏ قَالَتْ فَادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ ‏.‏ قَالَ فَدَعَا لَهَا ثُمَّ نَامَ الثَّانِيَةَ فَفَعَلَ مِثْلَهَا ثُمَّ قَالَتْ مِثْلَ قَوْلِهَا فَأَجَابَهَا مِثْلَ جَوَابِهِ الأَوَّلِ ‏.‏ قَالَتْ فَادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ قَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏ ‏.‏ قَالَ فَخَرَجَتْ مَعَ زَوْجِهَا عُبَادَةَ بْنِ الصَّامِتِ غَازِيَةً أَوَّلَ مَا رَكِبَ الْمُسْلِمُونَ الْبَحْرَ مَعَ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ فَلَمَّا انْصَرَفُوا مِنْ غَزَاتِهِمْ قَافِلِينَ فَنَزَلُوا الشَّامَ فَقُرِّبَتْ إِلَيْهَا دَابَّةٌ لِتَرْكَبَ فَصَرَعَتْهَا فَمَاتَتْ ‏.‏\hadithno{2776}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that his maternal aunt Umm Harim bint Milhan said:“The Messenger of Allah (ﷺ) slept near me one day, then he woke up smiling. I said: ‘O Messenger of Allah, what has made you smile?’ He said: ‘People of my nation who were shown to me (in my dream) riding across this sea like kings on thrones.’ I said: ‘Supplicate to Allah to make me one of them.’” So he prayed for her. Then he slept again, and did likewise, and she said the same as she said before, and he replied in the same manner. She said: “Pray to Allah to make me one of them,” and he said: “You will be one of the first ones.” He said: “Then she went out with her husband, ‘Ubadah bin Samit, as a fighter, the first time that the Muslims crossed the sea with Mu’awiyah bin Abu Sufyan. On their way back, after they had finished fighting, they stopped in Sham. An animal was brought near for her to ride it, but it threw her off, and she died.”}}
\hadithdefcmd{ibnmajah}{2777}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا بَقِيَّةُ، عَنْ مُعَاوِيَةَ بْنِ يَحْيَى، عَنْ لَيْثِ بْنِ أَبِي سُلَيْمٍ، عَنْ يَحْيَى بْنِ عَبَّادٍ، عَنْ أُمِّ الدَّرْدَاءِ، عَنْ أَبِي الدَّرْدَاءِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ غَزْوَةٌ فِي الْبَحْرِ مِثْلُ عَشْرِ غَزَوَاتٍ فِي الْبَرِّ وَالَّذِي يَسْدَرُ فِي الْبَحْرِ كَالْمُتَشَحِّطِ فِي دَمِهِ فِي سَبِيلِ اللَّهِ سُبْحَانَهُ ‏"‏ ‏.‏\hadithno{2777}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Sanad Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Darda’ that the Messenger of Allah (ﷺ) said:“A military expedition by sea is like ten expeditions by land. The one who suffers from seasickness is like one who gets drenched in his own blood in the cause of Allah.”}}
\hadithdefcmd{ibnmajah}{2778}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ يُوسُفَ الْجُبَيْرِيُّ، حَدَّثَنَا قَيْسُ بْنُ مُحَمَّدٍ الْكِنْدِيُّ، حَدَّثَنَا عُفَيْرُ بْنُ مَعْدَانَ الشَّامِيُّ، عَنْ سُلَيْمِ بْنِ عَامِرٍ، قَالَ سَمِعْتُ أَبَا أُمَامَةَ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ شَهِيدُ الْبَحْرِ مِثْلُ شَهِيدَىِ الْبَرِّ وَالْمَائِدُ فِي الْبَحْرِ كَالْمُتَشَحِّطِ فِي دَمِهِ فِي الْبَرِّ وَمَا بَيْنَ الْمَوْجَتَيْنِ كَقَاطِعِ الدُّنْيَا فِي طَاعَةِ اللَّهِ وَإِنَّ اللَّهَ عَزَّ وَجَلَّ وَكَلَ مَلَكَ الْمَوْتِ بِقَبْضِ الأَرْوَاحِ إِلاَّ شَهِيدَ الْبَحْرِ فَإِنَّهُ يَتَوَلَّى قَبْضَ أَرْوَاحِهِمْ وَيَغْفِرُ لِشَهِيدِ الْبَرِّ الذُّنُوبَ كُلَّهَا إِلاَّ الدَّيْنَ وَلِشَهِيدِ الْبَحْرِ الذُّنُوبَ وَالدَّيْنَ ‏"‏ ‏.‏\hadithno{2778}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Sulaim bin ‘Amr said:I heard Abu Umamah saying: I heard the Messenger of Allah (ﷺ) say: “The martyr at sea is like two martyrs on land, and the one who suffers seasickness is like one who gets drenched in his own blood on land. The time spent between one wave and the next is like a lifetime spent in obedience to Allah. Allah has appointed the Angel of Death to seize souls, except for the martyr at sea, for Allah Himself seizes their souls. He forgives the martyrs on land for all sins except debt, but (He forgives) the martyr at sea all his sins and his debt.”}}
\hadithdefcmd{ibnmajah}{2779}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا أَبُو دَاوُدَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ الْوَاسِطِيُّ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، ح وَحَدَّثَنَا عَلِيُّ بْنُ الْمُنْذِرِ، حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ، كُلُّهُمْ عَنْ قَيْسٍ، عَنْ أَبِي حُصَيْنٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لَوْ لَمْ يَبْقَ مِنَ الدُّنْيَا إِلاَّ يَوْمٌ لَطَوَّلَهُ اللَّهُ عَزَّ وَجَلَّ حَتَّى يَمْلِكَ رَجُلٌ مِنْ أَهْلِ بَيْتِي يَمْلِكُ جَبَلَ الدَّيْلَمِ وَالْقُسْطَنْطِينِيَّةَ ‏"‏ ‏.‏\hadithno{2779}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Even if there was only one day left of this world, Allah would make it last until a man from my household took possession of (the mountain of) Dailam and Constantinople.”}}
\hadithdefcmd{ibnmajah}{2780}{حَدَّثَنَا إِسْمَاعِيلُ بْنُ أَسَدٍ، حَدَّثَنَا دَاوُدُ بْنُ الْمُحَبَّرِ، أَنْبَأَنَا الرَّبِيعُ بْنُ صَبِيحٍ، عَنْ يَزِيدَ بْنِ أَبَانَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ سَتُفْتَحُ عَلَيْكُمُ الآفَاقُ وَسَتُفْتَحُ عَلَيْكُمْ مَدِينَةٌ يُقَالُ لَهَا قَزْوِينُ مَنْ رَابَطَ فِيهَا أَرْبَعِينَ يَوْمًا أَوْ أَرْبَعِينَ لَيْلَةً كَانَ لَهُ فِي الْجَنَّةِ عَمُودٌ مِنْ ذَهَبٍ عَلَيْهِ زَبَرْجَدَةٌ خَضْرَاءُ عَلَيْهَا قُبَّةٌ مِنْ يَاقُوتَةٍ حَمْرَاءَ لَهَا سَبْعُونَ أَلْفَ مِصْرَاعٍ مِنْ ذَهَبٍ عَلَى كُلِّ مِصْرَاعٍ زَوْجَةٌ مِنَ الْحُورِ الْعِينِ ‏"‏ ‏.‏\hadithno{2780}\hadithgrade{Al-Albani: Mawdu; Muhammad Fouad Abd al-Baqi: Mawdu; Shuaib Al Arnaut: Mawdu; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“The horizons will be opened to you, and you will conquer a city called Qazvin. Whoever is stationed there for forty days or forty nights, will have pillars of gold in Paradise, with green chrysolite and topped by a dome of rubies. It will have seventy thousand doors, at each door will be a wife from among the wide-eyed houris.’”}}
\hadithdefcmd{ibnmajah}{2781}{حَدَّثَنَا أَبُو يُوسُفَ، مُحَمَّدُ بْنُ أَحْمَدَ الرَّقِّيُّ حَدَّثَنَا مُحَمَّدُ بْنُ سَلَمَةَ الْحَرَّانِيُّ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ مُحَمَّدِ بْنِ طَلْحَةَ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ، عَنْ مُعَاوِيَةَ بْنِ جَاهِمَةَ السُّلَمِيِّ، قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ أَرَدْتُ الْجِهَادَ مَعَكَ أَبْتَغِي بِذَلِكَ وَجْهَ اللَّهِ وَالدَّارَ الآخِرَةَ ‏.‏ قَالَ ‏"‏ وَيْحَكَ أَحَيَّةٌ أُمُّكَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ ‏.‏ قَالَ ‏"‏ ارْجِعْ فَبَرَّهَا ‏"‏ ‏.‏ ثُمَّ أَتَيْتُهُ مِنَ الْجَانِبِ الآخَرِ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ أَرَدْتُ الْجِهَادَ مَعَكَ أَبْتَغِي بِذَلِكَ وَجْهَ اللَّهِ وَالدَّارَ الآخِرَةَ ‏.‏ قَالَ ‏"‏ وَيْحَكَ أَحَيَّةٌ أُمُّكَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ فَارْجِعْ إِلَيْهَا فَبَرَّهَا ‏"‏ ‏.‏ ثُمَّ أَتَيْتُهُ مِنْ أَمَامِهِ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنِّي كُنْتُ أَرَدْتُ الْجِهَادَ مَعَكَ أَبْتَغِي بِذَلِكَ وَجْهَ اللَّهِ وَالدَّارَ الآخِرَةَ ‏.‏ قَالَ ‏"‏ وَيْحَكَ أَحَيَّةٌ أُمُّكَ ‏"‏ ‏.‏ قُلْتُ نَعَمْ يَا رَسُولَ اللَّهِ ‏.‏ قَالَ ‏"‏ وَيْحَكَ الْزَمْ رِجْلَهَا فَثَمَّ الْجَنَّةُ ‏"‏ ‏.‏ حَدَّثَنَا هَارُونُ بْنُ عَبْدِ اللَّهِ الْحَمَّالُ، حَدَّثَنَا حَجَّاجُ بْنُ مُحَمَّدٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، أَخْبَرَنِي مُحَمَّدُ بْنُ طَلْحَةَ بْنِ عَبْدِ اللَّهِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ، عَنْ أَبِيهِ، طَلْحَةَ عَنْ مُعَاوِيَةَ بْنِ جَاهِمَةَ السُّلَمِيِّ، أَنَّ جَاهِمَةَ، أَتَى النَّبِيَّ صلى الله عليه وسلم فَذَكَرَ نَحْوَهُ ‏. ‏قَالَ أَبُو عَبْدِ اللَّهِ بْنُ مَاجَهْ هَذَا جَاهِمَةُ بْنُ عَبَّاسِ بْنِ مِرْدَاسٍ السُّلَمِيُّ الَّذِي عَاتَبَ النَّبِيَّ صلى الله عليه وسلم يَوْمَ حُنَيْنٍ ‏.‏\hadithno{2781}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated that Mu’awiyah bin Jahimah As-Sulaimi said:“I came to the Messenger of Allah (ﷺ) and said: ‘O Messenger of Allah, I want to go for Jihad with you, seeking thereby the Face of Allah and the Hereafter.’ He said: ‘Woe to you! Is your mother still alive?’ I said: ‘Yes.’ He said: ‘Go back and honor her.’ Then I approached him from the other side and said: ‘O Messenger of Allah, I want to go for Jihad with you, seeking thereby the Face of Allah and the Hereafter.’ He said: ‘Woe to you! Is your mother still alive?’ I said: ‘Yes.’ He said: ‘Go back and honour her.’ Then I approached him from in front and said: ‘O Messenger of Allah, I want to go for Jihad with you, seeking thereby the Face of Allah and the Hereafter.’ He said: ‘Woe to you! Is your mother still alive?’ I said: ‘Yes.’ He said: ‘Go back and serve her, for there is Paradise.’” Another chain reports a similar hadith. Ibn Majah said: This is Jahimah bin 'Abbas bin Mirdas As-Sulaimi who criticized the Prophet ﷺ the Day of Hunain}}
\hadithdefcmd{ibnmajah}{2782}{حَدَّثَنَا أَبُو كُرَيْبٍ، مُحَمَّدُ بْنُ الْعَلاَءِ حَدَّثَنَا الْمُحَارِبِيُّ، عَنْ عَطَاءِ بْنِ السَّائِبِ، عَنْ أَبِيهِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ أَتَى رَجُلٌ رَسُولَ اللَّهِ صلى الله عليه وسلم فَقَالَ يَا رَسُولَ اللَّهِ إِنِّي جِئْتُ أُرِيدُ الْجِهَادَ مَعَكَ أَبْتَغِي وَجْهَ اللَّهِ وَالدَّارَ الآخِرَةَ وَلَقَدْ أَتَيْتُ وَإِنَّ وَالِدَىَّ لَيَبْكِيَانِ ‏.‏ قَالَ ‏ "‏ فَارْجِعْ إِلَيْهِمَا فَأَضْحِكْهُمَا كَمَا أَبْكَيْتَهُمَا ‏"‏ ‏.‏\hadithno{2782}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Abdullah bin ‘Amr said:“A man came to the Messenger of Allah (ﷺ) and said: ‘O Messenger of Allah, I have come seeking to go out in Jihad with you, seeking thereby the Face of Allah and the Hereafter. I have come even though my parents are weeping.’ He said: ‘Go back to them and make them smile as you have made them weep.’”}}
\hadithdefcmd{ibnmajah}{2783}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقٍ، عَنْ أَبِي مُوسَى، قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنِ الرَّجُلِ يُقَاتِلُ شَجَاعَةً وَيُقَاتِلُ حَمِيَّةً وَيُقَاتِلُ رِيَاءً فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَاتَلَ لِتَكُونَ كَلِمَةُ اللَّهِ هِيَ الْعُلْيَا فَهُوَ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏\hadithno{2783}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Abu Musa said:“The Prophet (ﷺ) was asked about a man who fights to prove his courage, or out of pride and honour for his close relatives, or to show off. The Messenger of Allah (ﷺ) said: ‘Whoever fights so that the Word of Allah may be supreme is the one who (is fighting) in the cause of Allah.’”}}
\hadithdefcmd{ibnmajah}{2784}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حُسَيْنُ بْنُ مُحَمَّدٍ، حَدَّثَنَا جَرِيرُ بْنُ حَازِمٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ دَاوُدَ بْنِ الْحُصَيْنِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي عُقْبَةَ، عَنْ أَبِي عُقْبَةَ، - وَكَانَ مَوْلًى لأَهْلِ فَارِسَ - قَالَ شَهِدْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم يَوْمَ أُحُدٍ فَضَرَبْتُ رَجُلاً مِنَ الْمُشْرِكِينَ فَقُلْتُ خُذْهَا مِنِّي وَأَنَا الْغُلاَمُ الْفَارِسِيُّ ‏.‏ فَبَلَغَتِ النَّبِيَّ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَلاَ قُلْتَ خُذْهَا مِنِّي وَأَنَا الْغُلاَمُ الأَنْصَارِيُّ ‏"‏ ‏.‏\hadithno{2784}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Abu ‘Uqbah, who was the freed slave of some Persian people, said:“I was present with the Prophet (ﷺ) on the Day of Uhud. I struck a man from among the idolaters and said: ‘Take that! And I am a Persian slave!’ News of that reached the Prophet (ﷺ) and he said: ‘Why did you not say: “Take that! And I am an Ansari slave!?”}}
\hadithdefcmd{ibnmajah}{2785}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ يَزِيدَ، حَدَّثَنَا حَيْوَةُ، أَخْبَرَنِي أَبُو هَانِئٍ، أَنَّهُ سَمِعَ أَبَا عَبْدِ الرَّحْمَنِ الْحُبُلِيَّ، يَقُولُ إِنَّهُ سَمِعَ عَبْدَ اللَّهِ بْنَ عَمْرٍو، يَقُولُ سَمِعْتُ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَا مِنْ غَازِيَةٍ تَغْزُو فِي سَبِيلِ اللَّهِ فَيُصِيبُوا غَنِيمَةً إِلاَّ تَعَجَّلُوا ثُلُثَىْ أَجْرِهِمْ فَإِنْ لَمْ يُصِيبُوا غَنِيمَةً تَمَّ لَهُمْ أَجْرُهُمْ ‏"‏ ‏.‏\hadithno{2785}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{‘Abdullah bin ‘Amr said:“I heard the Prophet (ﷺ) say: ‘There is no band of warriors that fights in the cause of Allah and acquires war spoils, but they have been given two thirds of their reward, but if they do not get any spoils of war, then they will have their reward in full (in the Hereafter).’”}}
\hadithdefcmd{ibnmajah}{2786}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ شَبِيبِ بْنِ غَرْقَدَةَ، عَنْ عُرْوَةَ الْبَارِقِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْخَيْرُ مَعْقُودٌ بِنَوَاصِي الْخَيْلِ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2786}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from ‘Urwah Al-Bariqi that the Messenger of Allah (ﷺ) said:“Goodness is tied to the forelocks of horses until the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{2787}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنْ عَبْدِ اللَّهِ بْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ الْخَيْلُ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏\hadithno{2787}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Abdullah bin ‘Umar that the Messenger of Allah (ﷺ) said:“There is goodness in the forelocks of horses until the Day of Resurrection.”}}
\hadithdefcmd{ibnmajah}{2788}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْخَيْلُ فِي نَوَاصِيهَا الْخَيْرُ - أَوْ قَالَ الْخَيْلُ مَعْقُودٌ فِي نَوَاصِيهَا قَالَ سُهَيْلٌ أَنَا أَشُكُّ الْخَيْرُ - إِلَى يَوْمِ الْقِيَامَةِ الْخَيْلُ ثَلاَثَةٌ فَهِيَ لِرَجُلٍ أَجْرٌ وَلِرَجُلٍ سِتْرٌ وَعَلَى رَجُلٍ وِزْرٌ فَأَمَّا الَّذِي هِيَ لَهُ أَجْرٌ فَالرَّجُلُ يَتَّخِذُهَا فِي سَبِيلِ اللَّهِ وَيُعِدُّهَا لَهُ فَلاَ تُغَيِّبُ شَيْئًا فِي بُطُونِهَا إِلاَّ كُتِبَ لَهُ أَجْرٌ وَلَوْ رَعَاهَا فِي مَرْجٍ مَا أَكَلَتْ شَيْئًا إِلاَّ كُتِبَ لَهُ بِهَا أَجْرٌ وَلَوْ سَقَاهَا مِنْ نَهَرٍ جَارٍ كَانَ لَهُ بِكُلِّ قَطْرَةٍ تُغَيِّبُهَا فِي بُطُونِهَا أَجْرٌ - حَتَّى ذَكَرَ الأَجْرَ فِي أَبْوَالِهَا وَأَرْوَاثِهَا - وَلَوِ اسْتَنَّتْ شَرَفًا أَوْ شَرَفَيْنِ كُتِبَ لَهُ بِكُلِّ خَطْوَةٍ تَخْطُوهَا أَجْرٌ ‏.‏ وَأَمَّا الَّذِي هِيَ لَهُ سِتْرٌ فَالرَّجُلُ يَتَّخِذُهَا تَكَرُّمًا وَتَجَمُّلاً وَلاَ يَنْسَى حَقَّ ظُهُورِهَا وَبُطُونِهَا فِي عُسْرِهَا وَيُسْرِهَا ‏.‏ وَأَمَّا الَّذِي هِيَ عَلَيْهِ وِزْرٌ فَالَّذِي يَتَّخِذُهَا أَشَرًا وَبَطَرًا وَبَذَخًا وَرِياءً لِلنَّاسِ فَذَلِكَ الَّذِي هِيَ عَلَيْهِ وِزْرٌ ‏"‏ ‏.‏\hadithno{2788}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“There is goodness in the forelocks of horses” – or he said: “There is goodness tied in the forelocks of horses.” Suhail (one of the narrators) said: “I am not certain of” – “until the Day of Resurrection. And horses are of three types: those that bring reward to a man, those that are a means of protection for a man, and those that are a burden (of sin) for a man. As for those that bring reward, a man keeps them in the cause of Allah and keeps them constantly ready (for Jihad), so they do not take any fodder into their stomachs but a reward will be written for him, and if he puts them out to pasture, they do not eat anything but reward will be written for him. If he gives them to drink from a flowing river, for every drop that enters their stomachs there will be reward,” (continuing) until he mentioned reward in conjunction with their urine and droppings, and even when they run here and there by themselves, for each step they take a reward will be written for him – ‘As for those that are a means of protection, a man keeps them because they are a source of dignity and adornment, but he does not forget the rights of their backs and stomachs (i.e., their right not to be overworked and their right to be fed) whether at times of their difficulty or ease. As for those that bring a burden (of sin), the one who keeps them for purposes of wrongdoing or for pomp and show before people, is the one for whom they bring a burden of sin.”}}
\hadithdefcmd{ibnmajah}{2789}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا وَهْبُ بْنُ جَرِيرٍ، حَدَّثَنَا أَبِي قَالَ، سَمِعْتُ يَحْيَى بْنَ أَيُّوبَ، يُحَدِّثُ عَنْ يَزِيدَ بْنِ أَبِي حَبِيبٍ، عَنْ عُلَىِّ بْنِ رَبَاحٍ، عَنْ أَبِي قَتَادَةَ الأَنْصَارِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ خَيْرُ الْخَيْلِ الأَدْهَمُ الأَقْرَحُ الْمُحَجَّلُ الأَرْثَمُ طَلْقُ الْيَدِ الْيُمْنَى فَإِنْ لَمْ يَكُنْ أَدْهَمَ فَكُمَيْتٌ عَلَى هَذِهِ الشِّيَةِ ‏"‏ ‏.‏\hadithno{2789}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Qatadah Al-Ansari that the Messenger of Allah (ﷺ) said:“The best of horses are those that are deep black, with a blaze on the forehead, white marks on the legs and white nose and upper lip, and with no whiteness on the right foreleg. If not deep-black, then reddish-brown, with these markings.”}}
\hadithdefcmd{ibnmajah}{2790}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سَلْمِ بْنِ عَبْدِ الرَّحْمَنِ النَّخَعِيِّ، عَنْ أَبِي زُرْعَةَ بْنِ عَمْرِو بْنِ جَرِيرٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ كَانَ النَّبِيُّ صلى الله عليه وسلم يَكْرَهُ الشِّكَالَ مِنَ الْخَيْلِ ‏.‏\hadithno{2790}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Abu Hurairah said:“The Prophet (ﷺ) used to dislike horses that had three legs with white markings on them, and one leg the same color as the rest of the body.”}}
\hadithdefcmd{ibnmajah}{2791}{حَدَّثَنَا أَبُو عُمَيْرٍ، عِيسَى بْنُ مُحَمَّدٍ الرَّمْلِيُّ حَدَّثَنَا أَحْمَدُ بْنُ يَزِيدَ بْنِ رَوْحٍ الدَّارِيُّ، عَنْ مُحَمَّدِ بْنِ عُقْبَةَ الْقَاضِي، عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنْ تَمِيمٍ الدَّارِيِّ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنِ ارْتَبَطَ فَرَسًا فِي سَبِيلِ اللَّهِ ثُمَّ عَالَجَ عَلَفَهُ بِيَدِهِ كَانَ لَهُ بِكُلِّ حَبَّةٍ حَسَنَةٌ ‏"‏ ‏.‏\hadithno{2791}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Tamim Ad-Dari said:“I heard the Messenger of Allah (ﷺ) say: ‘Whoever ties a horse in the cause of Allah, then feeds it with his own hand, he will have one merit for every grain.’”}}
\hadithdefcmd{ibnmajah}{2792}{حَدَّثَنَا بِشْرُ بْنُ آدَمَ، حَدَّثَنَا الضَّحَّاكُ بْنُ مَخْلَدٍ، حَدَّثَنَا ابْنُ جُرَيْجٍ، حَدَّثَنَا سُلَيْمَانُ بْنُ مُوسَى، حَدَّثَنَا مَالِكُ بْنُ يُخَامِرَ، حَدَّثَنَا مُعَاذُ بْنُ جَبَلٍ، أَنَّهُ سَمِعَ النَّبِيَّ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ قَاتَلَ فِي سَبِيلِ اللَّهِ عَزَّ وَجَلَّ مِنْ رَجُلٍ مُسْلِمٍ فُوَاقَ نَاقَةٍ وَجَبَتْ لَهُ الْجَنَّةُ ‏"‏ ‏.‏\hadithno{2792}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Mu’adh bin Jabal narrated that he heard the Prophet (ﷺ) say:“Any Muslim who fights in the cause of Allah for the time between two milkings of a she-camel, he will be guaranteed Paradise.”}}
\hadithdefcmd{ibnmajah}{2793}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَفَّانُ، حَدَّثَنَا دَيْلَمُ بْنُ غَزْوَانَ، حَدَّثَنَا ثَابِتٌ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ حَضَرْتُ حَرْبًا فَقَالَ عَبْدُ اللَّهِ بْنُ رَوَاحَةَ يَا نَفْسِ أَلاَ أَرَاكِ تَكْرَهِينَ الْجَنَّهْ أَحْلِفُ بِاللَّهِ لَتَنْزِلِنَّهْ طَائِعَةً أَوْ لَتُكْرَهِنَّهْ\hadithno{2793}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Anas bin Malik said:“I was present in a war, and ‘Abdullah bin Rawahah said: O soul of mine! I see that you do Not want to go to Paradise. I swear by Allah that you surely Will enter it, willingly or Unwillingly.’”}}
\hadithdefcmd{ibnmajah}{2794}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَعْلَى بْنُ عُبَيْدٍ، حَدَّثَنَا حَجَّاجُ بْنُ دِينَارٍ، عَنْ مُحَمَّدِ بْنِ ذَكْوَانَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ عَمْرِو بْنِ عَبَسَةَ، قَالَ أَتَيْتُ النَّبِيَّ صلى الله عليه وسلم فَقُلْتُ يَا رَسُولَ اللَّهِ أَىُّ الْجِهَادِ أَفْضَلُ قَالَ ‏ "‏ مَنْ أُهْرِيقَ دَمُهُ وَعُقِرَ جَوَادُهُ ‏"‏ ‏.‏\hadithno{2794}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Amr bin ‘Abasah said:“I came to the Prophet (ﷺ) and said: ‘O Messenger of Allah, which Jihad is best?’ He said: ‘(That of a man) whose blood is shed and his horse is wounded.’”}}
\hadithdefcmd{ibnmajah}{2795}{حَدَّثَنَا بِشْرُ بْنُ آدَمَ، وَأَحْمَدُ بْنُ ثَابِتٍ الْجَحْدَرِيُّ، قَالاَ حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، حَدَّثَنَا مُحَمَّدُ بْنُ عَجْلاَنَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ مَجْرُوحٍ يُجْرَحُ فِي سَبِيلِ اللَّهِ - وَاللَّهُ أَعْلَمُ بِمَنْ يُجْرَحُ فِي سَبِيلِهِ - إِلاَّ جَاءَ يَوْمَ الْقِيَامَةِ وَجُرْحُهُ كَهَيْئَتِهِ يَوْمَ جُرِحَ وَاللَّوْنُ لَوْنُ دَمٍ وَالرِّيحُ رِيحُ مِسْكٍ ‏"‏ ‏.‏\hadithno{2795}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“There is no one who is wounded in the cause of Allah – and Allah knows best of who is wounded in His cause – but he will come on the Day of Resurrection with his wounds looking as they did on the day he was wounded; their color will be the color of blood but their smell will be the fragrance of musk.”}}
\hadithdefcmd{ibnmajah}{2796}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا يَعْلَى بْنُ عُبَيْدٍ، حَدَّثَنِي إِسْمَاعِيلُ بْنُ أَبِي خَالِدٍ، سَمِعْتُ عَبْدَ اللَّهِ بْنَ أَبِي أَوْفَى، يَقُولُ دَعَا رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى الأَحْزَابِ فَقَالَ ‏ "‏ اللَّهُمَّ مُنْزِلَ الْكِتَابِ سَرِيعَ الْحِسَابِ اهْزِمِ الأَحْزَابَ اللَّهُمَّ اهْزِمْهُمْ وَزَلْزِلْهُمْ ‏"‏ ‏.‏\hadithno{2796}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Isma’il bin Abu Khalid said:“I heard ‘Abdullah bin Abu Awfa say: ‘The Messenger of Allah (ﷺ) supplicated to Allah against the Confederates (Al-Ahzab) and said: ‘O Allah, Who has sent down the Book and is Swift in bringing to account, destroy the Confederates. O Allah, destroy them and shake them.’”}}
\hadithdefcmd{ibnmajah}{2797}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى، وَأَحْمَدُ بْنُ عِيسَى الْمِصْرِيَّانِ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، حَدَّثَنِي أَبُو شُرَيْحٍ عَبْدُ الرَّحْمَنِ بْنُ شُرَيْحٍ، أَنَّ سَهْلَ بْنَ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، حَدَّثَهُ عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ سَأَلَ اللَّهَ الشَّهَادَةَ بِصِدْقٍ مِنْ قَلْبِهِ بَلَّغَهُ اللَّهُ مَنَازِلَ الشُّهَدَاءِ وَإِنْ مَاتَ عَلَى فِرَاشِهِ ‏"‏ ‏.‏\hadithno{2797}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Sahl bin Abu Umamah bin Sahl bin Hunaif narrated from his father, from his grandfather that the Prophet (ﷺ) said:“Whoever asks Allah for martyrdom, sincerely from his heart, Allah will cause him to reach the status of the martyrs even if he dies in his bed.”}}
\hadithdefcmd{ibnmajah}{2798}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنِ ابْنِ عَوْنٍ، عَنْ هِلاَلِ بْنِ أَبِي زَيْنَبَ، عَنْ شَهْرِ بْنِ حَوْشَبٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ذُكِرَ الشُّهَدَاءُ عِنْدَ النَّبِيِّ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تَجِفُّ الأَرْضُ مِنْ دَمِ الشَّهِيدِ حَتَّى تَبْتَدِرَهُ زَوْجَتَاهُ كَأَنَّهُمَا ظِئْرَانِ أَضَلَّتَا فَصِيلَيْهِمَا فِي بَرَاحٍ مِنَ الأَرْضِ وَفِي يَدِ كُلِّ وَاحِدَةٍ مِنْهُمَا حُلَّةٌ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏\hadithno{2798}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Hurairah:“Mention of the martyrs was made in the presence of the Prophet (ﷺ) and he said: ‘The earth does not dry of the blood of the martyr until his two wives rush to him like two wet nurses who lost their young ones in a stretch of barren land, and in the hand of each one of them will be a Hullah* that is better than this world and everything in it.’”}}
\hadithdefcmd{ibnmajah}{2799}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، حَدَّثَنِي بَحِيرُ بْنُ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لِلشَّهِيدِ عِنْدَ اللَّهِ سِتُّ خِصَالٍ يُغْفَرُ لَهُ فِي أَوَّلِ دَفْعَةٍ مِنْ دَمِهِ وَيُرَى مَقْعَدَهُ مِنَ الْجَنَّةِ وَيُجَارُ مِنْ عَذَابِ الْقَبْرِ وَيَأْمَنُ مِنَ الْفَزَعِ الأَكْبَرِ وَيُحَلَّى حُلَّةَ الإِيمَانِ وَيُزَوَّجُ مِنَ الْحُورِ الْعِينِ وَيُشَفَّعُ فِي سَبْعِينَ إِنْسَانًا مِنْ أَقَارِبِهِ ‏"‏ ‏.‏\hadithno{2799}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Miqdam bin Ma’dikarib that the Messenger of Allah (ﷺ) said:“The martyr has six things (in store) with Allah: He is forgiven from the first drop of his blood that is shed; he is shown his place in Paradise; he is spared the torment of the grave; he is kept safe from the Great Fright; he is adorned with a garment of faith; he is married to (wives) from among the wide-eyed houris; and he is permitted to intercede for seventy of his relatives.”}}
\hadithdefcmd{ibnmajah}{2800}{حَدَّثَنَا إِبْرَاهِيمُ بْنُ الْمُنْذِرِ الْحَرَامِيُّ، حَدَّثَنَا مُوسَى بْنُ إِبْرَاهِيمَ الْحَرَامِيُّ الأَنْصَارِيُّ، سَمِعْتُ طَلْحَةَ بْنَ خِرَاشٍ، سَمِعْتُ جَابِرَ بْنَ عَبْدِ اللَّهِ، يَقُولُ لَمَّا قُتِلَ عَبْدُ اللَّهِ بْنُ عَمْرِو بْنِ حَرَامٍ يَوْمَ أُحُدٍ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ يَا جَابِرُ أَلاَ أُخْبِرُكَ مَا قَالَ اللَّهُ عَزَّ وَجَلَّ لأَبِيكَ ‏"‏ ‏.‏ قُلْتُ بَلَى ‏.‏ قَالَ ‏"‏ مَا كَلَّمَ اللَّهُ أَحَدًا إِلاَّ مِنْ وَرَاءِ حِجَابٍ وَكَلَّمَ أَبَاكَ كِفَاحًا ‏.‏ فَقَالَ يَا عَبْدِي تَمَنَّ عَلَىَّ أُعْطِكَ ‏.‏ قَالَ يَا رَبِّ تُحْيِينِي فَأُقْتَلُ فِيكَ ثَانِيَةً ‏.‏ قَالَ إِنَّهُ سَبَقَ مِنِّي أَنَّهُمْ إِلَيْهَا لاَ يُرْجَعُونَ ‏.‏ قَالَ يَا رَبِّ فَأَبْلِغْ مَنْ وَرَائِي ‏.‏ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ هَذِهِ الآيَةَ ‏\{وَلاَ تَحْسَبَنَّ الَّذِينَ قُتِلُوا فِي سَبِيلِ اللَّهِ أَمْوَاتًا‏\}‏ ‏"‏ ‏.‏ الآيَةَ كُلَّهَا ‏.‏\hadithno{2800}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir bin ‘Abdullah:“When ‘Abdullah bin ‘Amr bin Haram was killed, on the Day of Uhud, the Messenger of Allah (ﷺ) said: ‘O Jabir, shall I not tell you what Allah said to your father?’ I said: ‘Yes.’ He said: ‘Allah does not speak to anyone except from behind a screen, but He spoke to your father face to face and said: “O My slave, ask Me and I shall give you.” He said: “O my Lord, bring me back to life so that I may be killed for Your sake a second time.” He said: “I have already decreed that they will not return (to the world after death).” He said: “O Lord, convey (the good news about my state) to those whom I have left behind.” So Allah revealed this Verse: ‘Think not of those as dead who are killed in the way of Allah.’”[3:]}}
\hadithdefcmd{ibnmajah}{2801}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا الأَعْمَشُ، عَنْ عَبْدِ اللَّهِ بْنِ مُرَّةَ، عَنْ مَسْرُوقٍ، عَنْ عَبْدِ اللَّهِ، فِي قَوْلِهِ ‏\{وَلاَ تَحْسَبَنَّ الَّذِينَ قُتِلُوا فِي سَبِيلِ اللَّهِ أَمْوَاتًا بَلْ أَحْيَاءٌ عِنْدَ رَبِّهِمْ يُرْزَقُونَ‏\}‏ قَالَ أَمَا إِنَّا سَأَلْنَا عَنْ ذَلِكَ فَقَالَ ‏"‏ أَرْوَاحُهُمْ كَطَيْرٍ خُضْرٍ تَسْرَحُ فِي الْجَنَّةِ فِي أَيِّهَا شَاءَتْ ثُمَّ تَأْوِي إِلَى قَنَادِيلَ مُعَلَّقَةٍ بِالْعَرْشِ فَبَيْنَمَا هُمْ كَذَلِكَ إِذِ اطَّلَعَ عَلَيْهِمْ رَبُّكَ اطِّلاَعَةً فَيَقُولُ سَلُونِي مَا شِئْتُمْ ‏.‏ قَالُوا رَبَّنَا وَمَاذَا نَسْأَلُكَ وَنَحْنُ نَسْرَحُ فِي الْجَنَّةِ فِي أَيِّهَا شِئْنَا فَلَمَّا رَأَوْا أَنَّهُمْ لاَ يُتْرَكُونَ مِنْ أَنْ يَسْأَلُوا قَالُوا نَسْأَلُكَ أَنْ تَرُدَّ أَرْوَاحَنَا فِي أَجْسَادِنَا إِلَى الدُّنْيَا حَتَّى نُقْتَلَ فِي سَبِيلِكَ ‏.‏ فَلَمَّا رَأَى أَنَّهُمْ لاَ يَسْأَلُونَ إِلاَّ ذَلِكَ تُرِكُوا ‏"‏ ‏.‏\hadithno{2801}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Abdullah concerning the Verse:“Think not of those as dead who are killed in the way of Allah. Nay, they are alive, with their Lord, and they have provision,”[3:169] that he said: “We asked about that, and (the Prophet (ﷺ)) said: ‘Their souls are like green birds that fly wherever they wish in Paradise, then they come back to lamps suspended from the Throne. While they were like that, your Lord looked at them and said, “Ask me for whatever you want.” They said: “O Lord, what should we ask You for when we can fly wherever we wish in Paradise?” When they saw that they would not be left alone until they had asked for something, they said: “We ask You to return our souls to our bodies in the world so that we may fight for Your sake (again).” When He saw that they would not ask for anything but that, they were left alone.’”}}
\hadithdefcmd{ibnmajah}{2802}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَأَحْمَدُ بْنُ إِبْرَاهِيمَ الدَّوْرَقِيُّ، وَبِشْرُ بْنُ آدَمَ، قَالُوا حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، أَنْبَأَنَا مُحَمَّدُ بْنُ عَجْلاَنَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا يَجِدُ الشَّهِيدُ مَسَّ الْقَتْلِ إِلاَّ كَمَا يَجِدُ أَحَدُكُمْ مَسَّ الْقَرْصَةِ ‏"‏ ‏.‏\hadithno{2802}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The martyr does not feel anything more when he is killed than one of you feels if he is pinched (by a bug).”}}
\hadithdefcmd{ibnmajah}{2803}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ أَبِي الْعُمَيْسِ، عَنْ عَبْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ بْنِ جَابِرِ بْنِ عَتِيكٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، أَنَّهُ مَرِضَ فَأَتَاهُ النَّبِيُّ صلى الله عليه وسلم يَعُودُهُ فَقَالَ قَائِلٌ مِنْ أَهْلِهِ إِنْ كُنَّا لَنَرْجُو أَنْ تَكُونَ وَفَاتُهُ قَتْلَ شَهَادَةٍ فِي سَبِيلِ اللَّهِ ‏.‏ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ شُهَدَاءَ أُمَّتِي إِذًا لَقَلِيلٌ الْقَتْلُ فِي سَبِيلِ اللَّهِ شَهَادَةٌ وَالْمَطْعُونُ شَهَادَةٌ وَالْمَرْأَةُ تَمُوتُ بِجُمْعٍ شَهَادَةٌ - يَعْنِي الْحَامِلَ - وَالْغَرِقُ وَالْحَرِقُ وَالْمَجْنُوبُ - يَعْنِي ذَاتَ الْجَنْبِ - شَهَادَةٌ ‏"‏ ‏.‏\hadithno{2803}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Abdullah bin ‘Abdullah bin Jabir bin ‘Atik, from his father, that his grandfather fell sick and the Prophet (ﷺ) came to visit him. One of his family members said:“We hoped that when he died it would be as a martyr in the cause of Allah.” The Messenger of Allah (ﷺ) said: “In that case the martyrs of my nation would be few. Being killed in the cause of Allah is martyrdom; dying of the plague is martyrdom; when a pregnant woman dies in childbirth that is martyrdom; and dying of drowning, or burning, or of pleurisy, is martyrdom.”}}
\hadithdefcmd{ibnmajah}{2804}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ الْمَلِكِ بْنِ أَبِي الشَّوَارِبِ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ الْمُخْتَارِ، حَدَّثَنَا سُهَيْلٌ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ مَا تَقُولُونَ فِي الشَّهِيدِ فِيكُمْ ‏"‏ ‏.‏ قَالُوا الْقَتْلُ فِي سَبِيلِ اللَّهِ ‏.‏ قَالَ ‏"‏ إِنَّ شُهَدَاءَ أُمَّتِي إِذًا لَقَلِيلٌ مَنْ قُتِلَ فِي سَبِيلِ اللَّهِ فَهُوَ شَهِيدٌ وَمَنْ مَاتَ فِي سَبِيلِ اللَّهِ فَهُوَ شَهِيدٌ وَالْمَبْطُونُ شَهِيدٌ وَالْمَطْعُونُ شَهِيدٌ ‏"‏ ‏.‏ قَالَ سُهَيْلٌ وَأَخْبَرَنِي عُبَيْدُ اللَّهِ بْنُ مِقْسَمٍ، عَنْ أَبِي صَالِحٍ، وَزَادَ، فِيهِ ‏"‏ وَالْغَرِقُ شَهِيدٌ ‏"‏ ‏.‏\hadithno{2804}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Abu Hurairah that the Prophet (ﷺ) said:“What do you say among yourselves about the martyr?” They said: “The one who is killed in the cause of Allah.” He said: “In that case the martyrs among my nation would be few. Whoever is killed in the cause of Allah is a martyr; whoever dies in the cause of Allah is a martyr; whoever dies of a stomach disease is a martyr; and whoever dies of the plague is a martyr.” Another chain narrates with the addition of "and the drowned is a martyr}}
\hadithdefcmd{ibnmajah}{2805}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، وَسُوَيْدُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، حَدَّثَنِي الزُّهْرِيُّ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ مَكَّةَ يَوْمَ الْفَتْحِ وَعَلَى رَأْسِهِ الْمِغْفَرُ ‏.‏\hadithno{2805}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Anas bin Malik that the Prophet (ﷺ) entered Makkah on the day of the Conquest, with a helmet on his head}}
\hadithdefcmd{ibnmajah}{2806}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ يَزِيدَ بْنِ خُصَيْفَةَ، عَنِ السَّائِبِ بْنِ يَزِيدَ، إِنْ شَاءَ اللَّهُ تَعَالَى ‏.‏ أَنَّ النَّبِيَّ صلى الله عليه وسلم يَوْمَ أُحُدٍ أَخَذَ دِرْعَيْنِ كَأَنَّهُ ظَاهَرَ بَيْنَهُمَا ‏.‏\hadithno{2806}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Sa’ib bin Yazid, if Allah wills, that the Prophet (ﷺ) wore two coats of mail on the Day of Uhud, one over the other}}
\hadithdefcmd{ibnmajah}{2807}{حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ إِبْرَاهِيمَ الدِّمَشْقِيُّ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا الأَوْزَاعِيُّ، حَدَّثَنِي سُلَيْمَانُ بْنُ حَبِيبٍ، قَالَ دَخَلْنَا عَلَى أَبِي أُمَامَةَ فَرَأَى فِي سُيُوفِنَا شَيْئًا مِنْ حِلْيَةِ فِضَّةٍ فَغَضِبَ وَقَالَ لَقَدْ فَتَحَ الْفُتُوحَ قَوْمٌ مَا كَانَ حِلْيَةُ سُيُوفِهِمْ مِنَ الذَّهَبِ وَالْفِضَّةِ وَلَكِنِ الآنُكُ وَالْحَدِيدُ وَالْعَلاَبِيُّ ‏.‏ قَالَ أَبُو الْحَسَنِ الْقَطَّانُ الْعَلاَبِيُّ الْعَصَبُ ‏.‏\hadithno{2807}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Fouad Abd al-Baqi: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Sulaiman bin Habib said:“We entered upon Abu Umamah and he saw some silver ornaments on our swords. He got angry and said: ‘People conquered lands and their swords were not adorned with gold and silver, but with lead and iron and ‘Alabi.’”}}
\hadithdefcmd{ibnmajah}{2808}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا ابْنُ الصَّلْتِ، عَنِ ابْنِ أَبِي الزِّنَادِ، عَنْ أَبِيهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم تَنَفَّلَ سَيْفَهُ ذَا الْفِقَارِ يَوْمَ بَدْرٍ ‏.‏\hadithno{2808}\hadithgrade{Al-Albani: Hasan Isnaad; Muhammad Fouad Abd al-Baqi: Hasan Isnaad; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the Messenger of Allah (ﷺ) acquired his sword Dhulfiqar, from the spoils of war on the Day of badr}}
\hadithdefcmd{ibnmajah}{2809}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ سَمُرَةَ، أَنْبَأَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي إِسْحَاقَ، عَنْ أَبِي الْخَلِيلِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ كَانَ الْمُغِيرَةُ بْنُ شُعْبَةَ إِذَا غَزَا مَعَ النَّبِيِّ صلى الله عليه وسلم حَمَلَ مَعَهُ رُمْحًا فَإِذَا رَجَعَ طَرَحَ رُمْحَهُ حَتَّى يُحْمَلَ لَهُ ‏.‏ فَقَالَ لَهُ عَلِيٌّ لأَذْكُرَنَّ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ فَقَالَ ‏ "‏ لاَ تَفْعَلْ فَإِنَّكَ إِنْ فَعَلْتَ لَمْ تُرْفَعْ ضَالَّةٌ ‏"‏ ‏.‏\hadithno{2809}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali bin Abi Talib said:“When Mughirah bin Shu’bah fought alongside the Prophet (ﷺ) he would carry a spear, and when he would come back he would throw his spear down so that someone would pick it up and give it back to him.” ‘Ali said to him: “I will tell the Messenger of Allah (ﷺ) about that.” He (the Prophet (ﷺ)) said: “Do not do that, for it you do that it will not be picked up as a lost item to be returned.”}}
\hadithdefcmd{ibnmajah}{2810}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ سَمُرَةَ، أَنْبَأَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ أَشْعَثَ بْنِ سَعِيدٍ، عَنْ عَبْدِ اللَّهِ بْنِ بُسْرٍ، عَنْ أَبِي رَاشِدٍ، عَنْ عَلِيٍّ، قَالَ كَانَتْ بِيَدِ رَسُولِ اللَّهِ صلى الله عليه وسلم قَوْسٌ عَرَبِيَّةٌ فَرَأَى رَجُلاً بِيَدِهِ قَوْسٌ فَارِسِيَّةٌ فَقَالَ ‏ "‏ مَا هَذِهِ أَلْقِهَا وَعَلَيْكُمْ بِهَذِهِ وَأَشْبَاهِهَا وَرِمَاحِ الْقَنَا فَإِنَّهُمَا يَزِيدُ اللَّهُ بِهِمَا فِي الدِّينِ وَيُمَكِّنُ لَكُمْ فِي الْبِلاَدِ ‏"‏ ‏.‏\hadithno{2810}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Ali said:“The Messenger of Allah (ﷺ) had an Arabian bow in his hand, and he saw a man who had a Persian bow in his hand. He said: ‘What is this? Throw it away. You should use this and others like it, and Qana* spears. Perhaps Allah will support His religion thereby and enable you to conquer lands.’”}}
\hadithdefcmd{ibnmajah}{2811}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا هِشَامٌ الدَّسْتَوَائِيُّ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلاَّمٍ، عَنْ عَبْدِ اللَّهِ بْنِ الأَزْرَقِ، عَنْ عُقْبَةَ بْنِ عَامِرٍ الْجُهَنِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ إِنَّ اللَّهَ لَيُدْخِلُ بِالسَّهْمِ الْوَاحِدِ الثَّلاَثَةَ الْجَنَّةَ صَانِعَهُ يَحْتَسِبُ فِي صَنْعَتِهِ الْخَيْرَ وَالرَّامِيَ بِهِ وَالْمُمِدَّ بِهِ ‏"‏ ‏.‏ وَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ ارْمُوا وَارْكَبُوا وَأَنْ تَرْمُوا أَحَبُّ إِلَىَّ مِنْ أَنْ تَرْكَبُوا وَكُلُّ مَا يَلْهُو بِهِ الْمَرْءُ الْمُسْلِمُ بَاطِلٌ إِلاَّ رَمْيَهُ بِقَوْسِهِ وَتَأْدِيبَهُ فَرَسَهُ وَمُلاَعَبَتَهُ امْرَأَتَهُ فَإِنَّهُنَّ مِنَ الْحَقِّ ‏"‏ ‏.‏\hadithno{2811}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Uqbah bin ‘Amir Al-Juhani that the Prophet (ﷺ) said:“Allah will admit three people to Paradise by virtue of one arrow: The one who makes it, seeking reward by making it well; the one who shoots it; and the one who hands it to him.” And the Messenger of Allah (ﷺ) said: “Shoot and ride, and if you shoot that is dearer to me than if you ride. All things that a Muslim man does for entertainment are in vain except for shooting arrows, training his horse and playing with his wife, for these are things that bring reward.”}}
\hadithdefcmd{ibnmajah}{2812}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ سُلَيْمَانَ بْنِ عَبْدِ الرَّحْمَنِ، عَنِ الْقَاسِمِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عَمْرِو بْنِ عَبَسَةَ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ رَمَى الْعَدُوَّ بِسَهْمٍ فَبَلَغَ سَهْمُهُ الْعَدُوَّ أَصَابَ أَوْ أَخْطَأَ فَيَعْدِلُ رَقَبَةً ‏"‏ ‏.‏\hadithno{2812}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that ‘Amr bin ‘Abasah said:“I heard the Messenger of Allah (ﷺ) say: ‘Whoever shoots an arrow at the enemy and his arrow reaches the enemy, whether it hits him or not, that is equivalent to him freeing a slave.’”}}
\hadithdefcmd{ibnmajah}{2813}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي عَمْرُو بْنُ الْحَارِثِ، عَنْ أَبِي عَلِيٍّ الْهَمْدَانِيِّ، أَنَّهُ سَمِعَ عُقْبَةَ بْنَ عَامِرٍ الْجُهَنِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقْرَأُ عَلَى الْمِنْبَرِ ‏"‏ ‏\{وَأَعِدُّوا لَهُمْ مَا اسْتَطَعْتُمْ مِنْ قُوَّةٍ\}‏ أَلاَ وَإِنَّ الْقُوَّةَ الرَّمْىُ ‏"‏ ثَلاَثَ مَرَّاتٍ ‏.‏\hadithno{2813}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that ‘Uqbah bin ‘Amir Al-Juhani said:“I heard the Messenger of Allah (ﷺ) reciting on the pulpit: ‘And make ready against them all you can of power.’[8:60] (And saying that) three times – ‘Power means shooting.”}}
\hadithdefcmd{ibnmajah}{2814}{حَدَّثَنَا حَرْمَلَةُ بْنُ يَحْيَى الْمِصْرِيُّ، أَنْبَأَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، أَخْبَرَنِي ابْنُ لَهِيعَةَ، عَنْ عُثْمَانَ بْنِ نُعَيْمٍ الرُّعَيْنِيِّ، عَنِ الْمُغِيرَةِ بْنِ نَهِيكٍ، أَنَّهُ سَمِعَ عُقْبَةَ بْنَ عَامِرٍ الْجُهَنِيَّ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ تَعَلَّمَ الرَّمْىَ ثُمَّ تَرَكَهُ فَقَدْ عَصَانِي ‏"‏ ‏.‏\hadithno{2814}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that ‘Uqbah bin ‘Amir Al-Juhani said:“I heard the Messenger of Allah (ﷺ) say: ‘Whoever learns how to shoot (arrows) then abandons it, has disobeyed me.’”}}
\hadithdefcmd{ibnmajah}{2815}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَنْبَأَنَا سُفْيَانُ، عَنِ الأَعْمَشِ، عَنْ زِيَادِ بْنِ الْحُصَيْنِ، عَنْ أَبِي الْعَالِيَةِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ مَرَّ النَّبِيُّ صلى الله عليه وسلم بِنَفَرٍ يَرْمُونَ فَقَالَ ‏ "‏ رَمْيًا بَنِي إِسْمَاعِيلَ فَإِنَّ أَبَاكُمْ كَانَ رَامِيًا ‏"‏ ‏.‏\hadithno{2815}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Abbas said:“The Prophet (ﷺ) passed by some people who were shooting (arrows) and said: ‘Shoot, Banu Isma’il, for your father was an archer.’”}}
\hadithdefcmd{ibnmajah}{2816}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ عَاصِمٍ، عَنِ الْحَارِثِ بْنِ حَسَّانَ، قَالَ قَدِمْتُ الْمَدِينَةَ فَرَأَيْتُ النَّبِيَّ صلى الله عليه وسلم قَائِمًا عَلَى الْمِنْبَرِ وَبِلاَلٌ قَائِمٌ بَيْنَ يَدَيْهِ مُتَقَلِّدٌ سَيْفًا وَإِذَا رَايَةٌ سَوْدَاءُ فَقُلْتُ مَنْ هَذَا قَالُوا هَذَا عَمْرُو بْنُ الْعَاصِ قَدِمَ مِنْ غَزَاةٍ ‏.‏\hadithno{2816}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Harith bin Hassan said:“I came to Al-Madinah and saw the Prophet (ﷺ) standing on the pulpit, and Bilal standing in front of him, with his sword by his side, and (I saw) a black flag. I said: ‘Who is this?’ He said: ‘This is ‘Amr bin ‘As, who has just come back from a campaign.’”}}
\hadithdefcmd{ibnmajah}{2817}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، وَعَبْدَةُ بْنُ عَبْدِ اللَّهِ، قَالَ حَدَّثَنَا يَحْيَى بْنُ آدَمَ، حَدَّثَنَا شَرِيكٌ، عَنْ عَمَّارٍ الدُّهْنِيِّ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ مَكَّةَ يَوْمَ الْفَتْحِ وَلِوَاؤُهُ أَبْيَضُ ‏.‏\hadithno{2817}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Jabir bin ‘Abdullah that the Prophet (ﷺ) entered Makkah on the Day of the Conquest, and his standard was white}}
\hadithdefcmd{ibnmajah}{2818}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِسْحَاقَ الْوَاسِطِيُّ النَّاقِدُ، حَدَّثَنَا يَحْيَى بْنُ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ حَيَّانَ، سَمِعْتُ أَبَا مِجْلَزٍ، يُحَدِّثُ عَنِ ابْنِ عَبَّاسٍ، أَنَّ رَايَةَ، رَسُولِ اللَّهِ صلى الله عليه وسلم كَانَتْ سَوْدَاءَ وَلِوَاؤُهُ أَبْيَضُ ‏.‏\hadithno{2818}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Ibn ‘Abbas that the flag of the Messenger of Allah (ﷺ) was black, and his standard was white}}
\hadithdefcmd{ibnmajah}{2819}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ حَجَّاجٍ، عَنْ أَبِي عُمَرَ، - مَوْلَى أَسْمَاءَ - عَنْ أَسْمَاءَ بِنْتِ أَبِي بَكْرٍ، أَنَّهَا أَخْرَجَتْ جُبَّةً مُزَرَّرَةً بِالدِّيبَاجِ فَقَالَتْ كَانَ النَّبِيُّ صلى الله عليه وسلم يَلْبَسُ هَذِهِ إِذَا لَقِيَ الْعَدُوَّ ‏.‏\hadithno{2819}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu ‘Umar, the freed slave of Asma’, from Asma’ bint Abi Bakr, that she brought out a cloak edged with brocade and said:“The Prophet (ﷺ) used to wear this when he met the enemy.”}}
\hadithdefcmd{ibnmajah}{2820}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ عَاصِمٍ الأَحْوَلِ، عَنْ أَبِي عُثْمَانَ، عَنْ عُمَرَ، أَنَّهُ كَانَ يَنْهَى عَنِ الْحَرِيرِ، وَالدِّيبَاجِ، إِلاَّ مَا كَانَ هَكَذَا ثُمَّ أَشَارَ بِإِصْبَعِهِ ثُمَّ الثَّانِيَةِ ثُمَّ الثَّالِثَةِ ثُمَّ الرَّابِعَةِ وَقَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْهَانَا عَنْهُ ‏.‏\hadithno{2820}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Umar that he used to forbid silk and brocade except that which was like that, then he gestured with his finger, then his second finger, then his third, then his fourth,* and said:“The Messenger of Allah (ﷺ) used to forbid that to us.”}}
\hadithdefcmd{ibnmajah}{2821}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ مُسَاوِرٍ، حَدَّثَنِي جَعْفَرُ بْنُ عَمْرِو بْنِ حُرَيْثٍ، عَنْ أَبِيهِ، قَالَ كَأَنِّي أَنْظُرُ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ قَدْ أَرْخَى طَرَفَيْهَا بَيْنَ كَتِفَيْهِ ‏.‏\hadithno{2821}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Ja’far bin ‘Amr bin Huraith narrated that his father said:“It is as if I can see the Messenger of Allah (ﷺ), wearing a black turban, with its two ends hanging between his shoulders.”}}
\hadithdefcmd{ibnmajah}{2822}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا حَمَّادُ بْنُ سَلَمَةَ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم دَخَلَ مَكَّةَ وَعَلَيْهِ عِمَامَةٌ سَوْدَاءُ ‏.‏\hadithno{2822}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Jabir that the Prophet (ﷺ) entered Makkah wearing a black turban}}
\hadithdefcmd{ibnmajah}{2823}{حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ عَبْدِ الْكَرِيمِ، حَدَّثَنَا سُنَيْدُ بْنُ دَاوُدَ، عَنْ خَالِدِ بْنِ حَيَّانَ الرَّقِّيِّ، أَنْبَأَنَا عَلِيُّ بْنُ عُرْوَةَ الْبَارِقِيُّ، حَدَّثَنَا يُونُسُ بْنُ يَزِيدَ، عَنْ أَبِي الزِّنَادِ، عَنْ خَارِجَةَ بْنِ زَيْدٍ، قَالَ رَأَيْتُ رَجُلاً سَأَلَ أَبِي عَنِ الرَّجُلِ، يَغْزُو فَيَشْتَرِي وَيَبِيعُ وَيَتَّجِرُ فِي غَزْوِهِ فَقَالَ لَهُ أَبِي كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِتَبُوكَ نَشْتَرِي وَنَبِيعُ وَهُوَ يَرَانَا وَلاَ يَنْهَانَا ‏.‏\hadithno{2823}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Kharijah bin Zaid said:“I saw a man asking my father about a man who goes out to fight and buys and sells and trades during his campaign. My father said to him: ‘We were with the Messenger of Allah (ﷺ) in Tabuk, and we bought and sold, and he saw us and did not forbid us (to do that).’”}}
\hadithdefcmd{ibnmajah}{2824}{حَدَّثَنَا جَعْفَرُ بْنُ مُسَافِرٍ، حَدَّثَنَا أَبُو الأَسْوَدِ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ زَبَّانَ بْنِ فَائِدٍ، عَنْ سَهْلِ بْنِ مُعَاذِ بْنِ أَنَسٍ، عَنْ أَبِيهِ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لأَنْ أُشَيِّعَ مُجَاهِدًا فِي سَبِيلِ اللَّهِ فَأَكُفَّهُ عَلَى رَحْلِهِ غَدْوَةً أَوْ رَوْحَةً أَحَبُّ إِلَىَّ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏\hadithno{2824}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Sahl bin Mu’adh bin Anas, from his father, that the Messenger of Allah (ﷺ) said:“For me to hive a good send-off to a warrior who is going to fight in the cause of Allah, and to guard his goods when he goes out in the morning or evening, is dearer to me than this world and everything in it.”}}
\hadithdefcmd{ibnmajah}{2825}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنِ الْحَسَنِ بْنِ ثَوْبَانَ، عَنْ مُوسَى بْنِ وَرْدَانَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ وَدَّعَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ أَسْتَوْدِعُكَ اللَّهَ الَّذِي لاَ تَضِيعُ وَدَائِعُهُ ‏"‏ ‏.‏\hadithno{2825}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Abu Hurairah said:“The Messenger of Allah (ﷺ) gave me a send-off and said: ‘I command you to Allah’s keeping, Whose trust is never lost.’”}}
\hadithdefcmd{ibnmajah}{2826}{حَدَّثَنَا عَبَّادُ بْنُ الْوَلِيدِ، حَدَّثَنَا حَبَّانُ بْنُ هِلاَلٍ، حَدَّثَنَا أَبُو مِحْصَنٍ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَشْخَصَ السَّرَايَا يَقُولُ لِلشَّاخِصِ ‏ "‏ أَسْتَوْدِعُ اللَّهَ دِينَكَ وَأَمَانَتَكَ وَخَوَاتِيمَ عَمَلِكَ ‏"‏ ‏.‏\hadithno{2826}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Ibn ‘Umar said:“When the Messenger of Allah (ﷺ) would dispatch troops, he would say to the leader: ‘I commend to Allah’s keeping your religious commitment, your dignity and the end of your deeds.’”}}
\hadithdefcmd{ibnmajah}{2827}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ مُحَمَّدٍ الصَّنْعَانِيُّ، حَدَّثَنَا أَبُو سَلَمَةَ الْعَامِلِيُّ، عَنِ ابْنِ شِهَابٍ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ لأَكْثَمَ بْنِ الْجَوْنِ الْخُزَاعِيِّ ‏ "‏ يَا أَكْثَمُ اغْزُ مَعَ غَيْرِ قَوْمِكَ يَحْسُنْ خُلُقُكَ وَتَكْرُمْ عَلَى رُفَقَائِكَ يَا أَكْثَمُ خَيْرُ الرُّفَقَاءِ أَرْبَعَةٌ وَخَيْرُ السَّرَايَا أَرْبَعُمِائَةٍ وَخَيْرُ الْجُيُوشِ أَرْبَعَةُ آلاَفٍ وَلَنْ يُغْلَبَ اثْنَا عَشَرَ أَلْفًا مِنْ قِلَّةٍ ‏"‏ ‏.‏\hadithno{2827}\hadithgrade{Al-Albani: Very Daif; Muhammad Fouad Abd al-Baqi: Very Daif; Shuaib Al Arnaut: Very Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said to Aktham bin Al-Jawn Al-Khuza’i:“O Aktham! Fight alongside people other than your own, it will improve your attitude and make you generous to your companions. O Aktham, the best number of companions is four, the best number of troops on an expedition is four hundred, the best number of an army is four thousand, and twelve thousand will never be overpowered because of their small number.”}}
\hadithdefcmd{ibnmajah}{2828}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا أَبُو عَامِرٍ، حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي إِسْحَاقَ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ كُنَّا نَتَحَدَّثُ أَنَّ أَصْحَابَ، رَسُولِ اللَّهِ صلى الله عليه وسلم كَانُوا يَوْمَ بَدْرٍ ثَلاَثَمِائَةٍ وَبِضْعَةَ عَشَرَ عَلَى عِدَّةِ أَصْحَابِ طَالُوتَ مَنْ جَازَ مَعَهُ النَّهَرَ وَمَا جَازَ مَعَهُ إِلاَّ مُؤْمِنٌ ‏.‏\hadithno{2828}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Bara’ bin ‘Azib said:“We were talking about how, on the Day of Badr, the Companions of the Messenger of Allah (ﷺ) numbered three hundred ten and something, the same number as the Companions of (Talut) who crossed the river with him, and no one crossed the river with him but a believer.”}}
\hadithdefcmd{ibnmajah}{2829}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا زَيْدُ بْنُ الْحُبَابِ، عَنِ ابْنِ لَهِيعَةَ، أَخْبَرَنِي يَزِيدُ بْنُ أَبِي حَبِيبٍ، عَنْ لَهِيعَةَ بْنِ عُقْبَةَ، قَالَ سَمِعْتُ أَبَا الْوَرْدِ، صَاحِبَ النَّبِيِّ صلى الله عليه وسلم يَقُولُ إِيَّاكُمْ وَالسَّرِيَّةَ الَّتِي إِنْ لَقِيَتْ فَرَّتْ وَإِنْ غَنِمَتْ غَلَّتْ ‏.‏\hadithno{2829}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Lahi’ah bin ‘Uqbah said:“I heard Abul-Ward, the Companion of the Messenger of Allah (ﷺ), say: ‘Beware of the troop which, when it meets (the enemy) it flees, and when it takes spoils of war, it steals from it.’”}}
\hadithdefcmd{ibnmajah}{2830}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ سِمَاكِ بْنِ حَرْبٍ، عَنْ قَبِيصَةَ بْنِ هُلْبٍ، عَنْ أَبِيهِ، قَالَ سَأَلْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنْ طَعَامِ النَّصَارَى فَقَالَ ‏ "‏ لاَ يَخْتَلِجَنَّ فِي صَدْرِكَ طَعَامٌ ضَارَعْتَ فِيهِ نَصْرَانِيَّةً ‏"‏ ‏.‏\hadithno{2830}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated from Qabisah bin Hulb that his father said:“I asked the Messenger of Allah (ﷺ) about the food of the Christians and he said: ‘Do not have any doubt about food, (thereby) following the way of the Christians in that.’”}}
\hadithdefcmd{ibnmajah}{2831}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنِي أَبُو فَرْوَةَ، يَزِيدُ بْنُ سِنَانٍ حَدَّثَنِي عُرْوَةُ بْنُ، رُوَيْمٍ اللَّخْمِيُّ، عَنْ أَبِي ثَعْلَبَةَ الْخُشَنِيِّ، - قَالَ وَلَقِيَهُ وَكَلَّمَهُ - قَالَ أَتَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم فَسَأَلْتُهُ فَقُلْتُ يَا رَسُولَ اللَّهِ قُدُورُ الْمُشْرِكِينَ نَطْبُخُ فِيهَا قَالَ ‏"‏ لاَ تَطْبُخُوا فِيهَا ‏"‏ ‏.‏ قُلْتُ فَإِنِ احْتَجْنَا إِلَيْهَا فَلَمْ نَجِدْ مِنْهَا بُدًّا قَالَ ‏"‏ فَارْحَضُوهَا رَحْضًا حَسَنًا ثُمَّ اطْبُخُوا وَكُلُوا ‏"‏ ‏.‏\hadithno{2831}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{‘Urwah bin Ruwaim Al-Lakhmi narrated that Abu Tha’labah Al-Khushani – whom he said he met and spoke with – said:“I came to the Messenger of Allah (ﷺ) and asked him: ‘O Messenger of Allah! Can we cook in the vessels of the idolaters?’ He said: ‘Do not cook in them.’ I said: ‘What if we need them and cannot find anything else?’ He said: ‘Wash them well, then cook and eat.’”}}
\hadithdefcmd{ibnmajah}{2832}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ عَبْدِ اللَّهِ بْنِ يَزِيدَ، عَنْ نِيَارٍ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ عَائِشَةَ، قَالَتْ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّا لاَ نَسْتَعِينُ بِمُشْرِكٍ ‏"‏ ‏.‏ قَالَ عَلِيٌّ فِي حَدِيثِهِ عَبْدُ اللَّهِ بْنُ يَزِيدَ أَوْ زَيْدٍ ‏.‏\hadithno{2832}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from ‘Aishah that the Messenger of Allah (ﷺ) said:‘We do not seek the help of the polytheist.”}}
\hadithdefcmd{ibnmajah}{2833}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ يَزِيدَ بْنِ رُومَانَ، عَنْ عُرْوَةَ، عَنْ عَائِشَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الْحَرْبُ خُدْعَةٌ ‏"‏ ‏.‏\hadithno{2833}\hadithgrade{Al-Albani: Sahih Mutawatir; Muhammad Fouad Abd al-Baqi: Sahih Mutawatir; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Aishah that the Prophet (ﷺ) said:“War is deceit.”}}
\hadithdefcmd{ibnmajah}{2834}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا يُونُسُ بْنُ بُكَيْرٍ، عَنْ مَطَرِ بْنِ مَيْمُونٍ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ الْحَرْبُ خُدْعَةٌ ‏"‏ ‏.‏\hadithno{2834}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Ibn ‘Abbas that the Prophet (ﷺ) said:“War is deceit.”}}
\hadithdefcmd{ibnmajah}{2835}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، وَحَفْصُ بْنُ عَمْرٍو، قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، أَنْبَأَنَا وَكِيعٌ، قَالاَ حَدَّثَنَا سُفْيَانُ، عَنْ أَبِي هَاشِمٍ الرُّمَّانِيِّ، - قَالَ أَبُو عَبْدِ اللَّهِ هُوَ يَحْيَى بْنُ الأَسْوَدِ - عَنْ أَبِي مِجْلَزٍ، عَنْ قَيْسِ بْنِ عُبَادٍ، قَالَ سَمِعْتُ أَبَا ذَرٍّ، يُقْسِمُ لَنَزَلَتْ هَذِهِ الآيَاتُ فِي هَؤُلاَءِ الرَّهْطِ السِّتَّةِ يَوْمَ بَدْرٍ ‏\{‏هَذَانِ خَصْمَانِ اخْتَصَمُوا فِي رَبِّهِمْ‏\}‏ إِلَى قَوْلِهِ‏:‏ ‏\{‏ إِنَّ اللَّهَ يَفْعَلُ مَا يُرِيدُ‏\}‏ فِي حَمْزَةَ بْنِ عَبْدِ الْمُطَّلِبِ وَعَلِيِّ بْنِ أَبِي طَالِبٍ وَعُبَيْدَةَ بْنِ الْحَارِثِ وَعُتْبَةَ بْنِ رَبِيعَةَ وَشَيْبَةَ بْنِ رَبِيعَةَ وَالْوَلِيدِ بْنِ عُتْبَةَ اخْتَصَمُوا فِي الْحُجَجِ يَوْمَ بَدْرٍ ‏.‏\hadithno{2835}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Qais bin ‘Ubaid said:“I heard Abu Dharr swearing that these verses were revealed concerning those six people on the Day of Badr: ‘These two opponents (believers and disbelievers) dispute with each other about their Lord.”[22:19] to the words “Verily, Allah does what he wills.’[22:14] (that is) Hamzah bin ‘Abdul-Muttalib, ‘Ali bin Abi Talib, ‘Ubaidah bin Al-Harith, ‘Utbah bin Rabi’ah, Shaibah bin Rabi’ah and Al-Walid bin ‘Utbah. They argued with one another on the Day of Badr.”}}
\hadithdefcmd{ibnmajah}{2836}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا أَبُو الْعُمَيْسِ، وَعِكْرِمَةُ بْنُ عَمَّارٍ، عَنْ إِيَاسِ بْنِ سَلَمَةَ بْنِ الأَكْوَعِ، عَنْ أَبِيهِ، قَالَ بَارَزْتُ رَجُلاً فَقَتَلْتُهُ فَنَفَّلَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم سَلَبَهُ ‏.‏\hadithno{2836}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Fouad Abd al-Baqi: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Iyas bin Salamah bin Akwa’ that his father said:“I fought a man and killed him, and the Messenger of Allah (ﷺ) awarded me his spoils.”}}
\hadithdefcmd{ibnmajah}{2837}{حَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، أَنْبَأَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ عُمَرَ بْنِ كَثِيرِ بْنِ أَفْلَحَ، عَنْ أَبِي مُحَمَّدٍ، مَوْلَى أَبِي قَتَادَةَ عَنْ أَبِي قَتَادَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَفَّلَهُ سَلَبَ قَتِيلٍ قَتَلَهُ يَوْمَ حُنَيْنٍ ‏.‏\hadithno{2837}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Muhammad, the freed slave of Abu Qatadah (from Abu Qatadah) that the Messenger of Allah (ﷺ) awarded him the spoils of a man whom he killed on the Day of Hunain}}
\hadithdefcmd{ibnmajah}{2838}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، حَدَّثَنَا أَبُو مَالِكٍ الأَشْجَعِيُّ، عَنْ نُعَيْمِ بْنِ أَبِي هِنْدٍ، عَنِ ابْنِ سَمُرَةَ بْنِ جُنْدُبٍ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ قَتَلَ فَلَهُ السَّلَبُ ‏"‏ ‏.‏\hadithno{2838}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from the son of Samurah bin Jundub that his father said:“The Messenger of Allah (ﷺ) said: ‘Whoever kills, the spoils are his.’”}}
\hadithdefcmd{ibnmajah}{2839}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ الزُّهْرِيِّ، عَنْ عُبَيْدِ اللَّهِ بْنِ عَبْدِ اللَّهِ، عَنِ ابْنِ عَبَّاسٍ، قَالَ حَدَّثَنَا الصَّعْبُ بْنُ جَثَّامَةَ، قَالَ سُئِلَ النَّبِيُّ صلى الله عليه وسلم عَنْ أَهْلِ الدَّارِ مِنَ الْمُشْرِكِينَ يُبَيَّتُونَ فَيُصَابُ النِّسَاءُ وَالصِّبْيَانُ قَالَ ‏ "‏ هُمْ مِنْهُمْ ‏"‏ ‏.‏\hadithno{2839}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that Ibn ‘Abbas said:“Sa’b bin Jaththamah said: ‘The Prophet (ﷺ) was asked about the polytheists who are attacked at night, and their women and children are killed.’ He said: ‘They are from among them.’”}}
\hadithdefcmd{ibnmajah}{2840}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ، أَنْبَأَنَا وَكِيعٌ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، عَنْ إِيَاسِ بْنِ سَلَمَةَ بْنِ الأَكْوَعِ، عَنْ أَبِيهِ، قَالَ غَزَوْنَا مَعَ أَبِي بَكْرٍ هَوَازِنَ عَلَى عَهْدِ النَّبِيِّ صلى الله عليه وسلم فَأَتَيْنَا مَاءً لِبَنِي فَزَارَةَ فَعَرَّسْنَا حَتَّى إِذَا كَانَ عِنْدَ الصُّبْحُ شَنَنَّاهَا عَلَيْهِمْ غَارَةً فَأَتَيْنَا أَهْلَ مَاءٍ فَبَيَّتْنَاهُمْ فَقَتَلْنَاهُمْ تِسْعَةً أَوْ سَبْعَةَ أَبْيَاتٍ ‏.‏\hadithno{2840}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Iyas bin Salamah bin Awka’, that his father said:“We attacked Hawazin, with Abu Bakr, during the time of the Prophet (ﷺ), and we arrived at an oasis belonging to Bani Fazarah during the last part of the night. We attacked at dawn, raiding the people of the oasis, and killed them, nine or seven households.”}}
\hadithdefcmd{ibnmajah}{2841}{حَدَّثَنَا يَحْيَى بْنُ حَكِيمٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَنْبَأَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم رَأَى امْرَأَةً مَقْتُولَةً فِي بَعْضِ الطَّرِيقِ فَنَهَى عَنْ قَتْلِ النِّسَاءِ وَالصِّبْيَانِ ‏.‏\hadithno{2841}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) saw a woman who had been killed on the road, and he forbade killing women and children}}
\hadithdefcmd{ibnmajah}{2842}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ أَبِي الزِّنَادِ، عَنِ الْمُرَقَّعِ بْنِ عَبْدِ اللَّهِ بْنِ صَيْفِيٍّ، عَنْ حَنْظَلَةَ الْكَاتِبِ، قَالَ غَزَوْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فَمَرَرْنَا عَلَى امْرَأَةٍ مَقْتُولَةٍ قَدِ اجْتَمَعَ عَلَيْهَا النَّاسُ فَأَفْرَجُوا لَهُ فَقَالَ ‏(‏مَا كَانَتْ هَذِهِ تُقَاتِلُ فِيمَنْ يُقَاتِلُ‏)‏ ‏.‏ ثُمَّ قَالَ لِرَجُلٍ ‏(‏انْطَلِقْ إِلَى خَالِدِ بْنِ الْوَلِيدِ فَقُلْ لَهُ إِنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم يَأْمُرُكَ يَقُولُ لاَ تَقْتُلَنَّ ذُرِّيَّةً وَلاَ عَسِيفًا‏)‏‏.‏ حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا الْمُغِيرَةُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي الزِّنَادِ، عَنِ الْمُرَقَّعِ، عَنْ جَدِّهِ، رَبَاحِ بْنِ الرَّبِيعِ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ.‏ قَالَ أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ يُخْطِئُ الثَّوْرِيُّ فِيهِ.‏\hadithno{2842}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated that Hanzalah Al-Katib said:“We went out to fight alongside the Messenger of Allah (ﷺ), and we passed by a slain woman whom the people had gathered around. They parted (to let the Prophet (ﷺ) through) and he said: ‘This (woman) was not one of those who were fighting.’ Then he said to a man: ‘Go to Khalid bin Walid and tell him that the Messenger of Allah (ﷺ) commands you: “Do not kill any children or women, or any (farm) laborer.’” Another chain reports a similar hadith}}
\hadithdefcmd{ibnmajah}{2843}{حَدَّثَنَا مُحَمَّدُ بْنُ إِسْمَاعِيلَ بْنِ سَمُرَةَ، حَدَّثَنَا وَكِيعٌ، عَنْ صَالِحِ بْنِ أَبِي الأَخْضَرِ، عَنِ الزُّهْرِيِّ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، عَنْ أُسَامَةَ بْنِ زَيْدٍ، قَالَ بَعَثَنِي رَسُولُ اللَّهِ صلى الله عليه وسلم إِلَى قَرْيَةٍ يُقَالُ لَهَا أُبْنَى فَقَالَ ‏ "‏ ائْتِ أُبْنَى صَبَاحًا ثُمَّ حَرِّقْ ‏"‏ ‏.‏\hadithno{2843}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated that Usamah bin Said said:“The Messenger of Allah (ﷺ) sent me to a village called Ubna, and said: “Go to Ubna in the morning and burn it.’”}}
\hadithdefcmd{ibnmajah}{2844}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم حَرَّقَ نَخْلَ بَنِي النَّضِيرِ وَقَطَعَ ‏.‏ وَهِيَ الْبُوَيْرَةُ فَأَنْزَلَ اللَّهُ عَزَّ وَجَلَّ ‏\{مَا قَطَعْتُمْ مِنْ لِينَةٍ أَوْ تَرَكْتُمُوهَا قَائِمَةً \}‏ الآيَةَ ‏.‏\hadithno{2844}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) burned the palm trees of Banu Nadir, and cut down Buwairah (the name of their garden). Then Allah revealed the words:“What you (O Muslims) cut down of the palm trees (of the enemy), or you left them standing...” [59:]}}
\hadithdefcmd{ibnmajah}{2845}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ سَعِيدٍ، حَدَّثَنَا عُقْبَةُ بْنُ خَالِدٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم حَرَّقَ نَخْلَ بَنِي النَّضِيرِ وَقَطَعَ ‏.‏ وَفِيهِ يَقُولُ شَاعِرُهُمْ فَهَانَ عَلَى سَرَاةِ بَنِي لُؤَىٍّ حَرِيقٌ بِالْبُوَيْرَةِ مُسْتَطِيرُ\hadithno{2845}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) burned the palm trees of Banu Nadir and cut them down. Concerning that, their poet said: “It is easy for the elite of Banu Luai – To burn Al-Buwairah in a Frightening manner.”}}
\hadithdefcmd{ibnmajah}{2846}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، وَمُحَمَّدُ بْنُ إِسْمَاعِيلَ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ عِكْرِمَةَ بْنِ عَمَّارٍ، عَنْ إِيَاسِ بْنِ سَلَمَةَ بْنِ الأَكْوَعِ، عَنْ أَبِيهِ، قَالَ غَزَوْنَا مَعَ أَبِي بَكْرٍ هَوَازِنَ عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَنَفَّلَنِي جَارِيَةً مِنْ بَنِي فَزَارَةَ مِنْ أَجْمَلِ الْعَرَبِ عَلَيْهَا قِشْعٌ لَهَا فَمَا كَشَفْتُ لَهَا عَنْ ثَوْبٍ حَتَّى أَتَيْتُ الْمَدِينَةَ فَلَقِيَنِي النَّبِيُّ صلى الله عليه وسلم فِي السُّوقِ فَقَالَ ‏ "‏ لِلَّهِ أَبُوكَ هَبْهَا لِي ‏"‏ ‏.‏ فَوَهَبْتُهَا لَهُ فَبَعَثَ بِهَا فَفَادَى بِهَا أُسَارَى مِنْ أُسَارَى الْمُسْلِمِينَ كَانُوا بِمَكَّةَ ‏.‏\hadithno{2846}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ayas bin Salamah bin Akwa’ that his father said:“We attacked, Hawazin at the time of the Messenger of Allah (ﷺ) with Aby Bakr. He awarded me a slave girl from Banu Fazarah, among the most beautiful of the Arabs, who was wearing an animal skin of hers. I did not divest her of her clothing until I reached Al-Madinah. Then the Prophet (ﷺ) met me in the marketplace, and said: ‘By Alla, give her to me.’ So I gave her to him, and he sent her as a ransom for some of the Muslim prisoners who were in Makkah.”}}
\hadithdefcmd{ibnmajah}{2847}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ ذَهَبَتْ فَرَسٌ لَهُ فَأَخَذَهَا الْعَدُوُّ فَظَهَرَ عَلَيْهِمُ الْمُسْلِمُونَ فَرُدَّ عَلَيْهِ فِي زَمَنِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏ قَالَ وَأَبَقَ عَبْدٌ لَهُ فَلَحِقَ بِالرُّومِ فَظَهَرَ عَلَيْهِمُ الْمُسْلِمُونَ فَرَدَّهُ عَلَيْهِ خَالِدُ بْنُ الْوَلِيدِ بَعْدَ وَفَاةِ رَسُولِ اللَّهِ صلى الله عليه وسلم ‏.‏\hadithno{2847}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that Ibn ‘Umar said that a horse of his went out and the enemy captured it. Then the Muslims defeated them and it was returned to him. (That was) during the time of the Messenger of Allah (ﷺ). He said:“And a slave of his absconded and joined up with the Romans, then the Muslims defeated them, and Khalid bin Walid returned him to me, after the death of the Messenger of Allah (ﷺ).”}}
\hadithdefcmd{ibnmajah}{2848}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ يَحْيَى بْنِ حَبَّانَ، عَنْ أَبِي عَمْرَةَ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ تُوُفِّيَ رَجُلٌ مِنْ أَشْجَعَ بِخَيْبَرَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ صَلُّوا عَلَى صَاحِبِكُمْ ‏"‏ ‏.‏ فَأَنْكَرَ النَّاسُ ذَلِكَ وَتَغَيَّرَتْ لَهُ وُجُوهُهُمْ فَلَمَّا رَأَى ذَلِكَ قَالَ ‏"‏ إِنَّ صَاحِبَكُمْ غَلَّ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ زَيْدٌ فَالْتَمَسُوا فِي مَتَاعِهِ فَإِذَا خَرَزَاتٌ مِنْ خَرَزِ يَهُودَ مَا تُسَاوِي دِرْهَمَيْنِ ‏.‏\hadithno{2848}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Zaid bin Khalid Al-Juhani said:“A man from (the tribe of) Ashja’ died in Khaibar, and the Prophet (ﷺ) said: ‘Offer the funeral prayer for your companion.’ The people found that strange.* When he saw that, he said: ‘Your companion stole from the spoils of war (when fighting) in the cause of Allah.’”}}
\hadithdefcmd{ibnmajah}{2849}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ عَبْدِ اللَّهِ بْنِ عَمْرٍو، قَالَ كَانَ عَلَى ثَقَلِ النَّبِيِّ صلى الله عليه وسلم رَجُلٌ يُقَالُ لَهُ كِرْكِرَةُ ‏.‏ فَمَاتَ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ هُوَ فِي النَّارِ ‏"‏ ‏.‏ فَذَهَبُوا يَنْظُرُونَ فَوَجَدُوا عَلَيْهِ كِسَاءً أَوْ عَبَاءَةً قَدْ غَلَّهَا ‏.‏\hadithno{2849}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated that ‘Abdullah bin ‘Amr said:“There was a man called Kirkah in charge of the goods of the Prophet (ﷺ), who died. The Prophet (ﷺ) said: ‘He is in Hell.’ They went and looked, and found him wearing a garment or a cloak that he had stolen from the spoils of war.”}}
\hadithdefcmd{ibnmajah}{2850}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو أُسَامَةَ، عَنْ أَبِي سِنَانٍ، عِيسَى بْنِ سِنَانٍ عَنْ يَعْلَى بْنِ شَدَّادٍ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ صَلَّى بِنَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمَ حُنَيْنٍ إِلَى جَنْبِ بَعِيرٍ مِنَ الْمَقَاسِمِ ثُمَّ تَنَاوَلَ شَيْئًا مِنَ الْبَعِيرِ فَأَخَذَ مِنْهُ قَرَدَةً - يَعْنِي وَبَرَةً - فَجَعَلَ بَيْنَ إِصْبَعَيْهِ ثُمَّ قَالَ ‏ "‏ يَا أَيُّهَا النَّاسُ إِنَّ هَذَا مِنْ غَنَائِمِكُمْ أَدُّوا الْخَيْطَ وَالْمِخْيَطَ فَمَا فَوْقَ ذَلِكَ فَمَا دُونَ ذَلِكَ فَإِنَّ الْغُلُولَ عَارٌ عَلَى أَهْلِهِ يَوْمَ الْقِيَامَةِ وَشَنَارٌ وَنَارٌ ‏"‏ ‏.‏\hadithno{2850}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Hasan}\hadithtrans{It was narrated that ‘Ubadah bin Samit said:“The Messenger of Allah (ﷺ) led us in prayer on the Day of Hunain, beside a camel that was part of the spoils of war. Then he took something from the camel, and extracted from it a hair, which he placed between two of his fingers. Then he said: ‘O people, this is part of your spoils of war. Hand over a needle and thread and anything greater than that or less than that. For stealing from the spoils of war will be a source of shame for those who do it, and ignominy and Fire, on the Day of Resurrection.’”}}
\hadithdefcmd{ibnmajah}{2851}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ يَزِيدَ بْنِ يَزِيدَ بْنِ جَابِرٍ، عَنْ مَكْحُولٍ، عَنْ زَيْدِ بْنِ جَارِيَةَ، عَنْ حَبِيبِ بْنِ مَسْلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَفَّلَ الثُّلُثَ بَعْدَ الْخُمُسِ ‏.‏\hadithno{2851}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Habib bin Maslamah that the Prophet (ﷺ) awarded one third (of the spoils of war) after the one fifth (had been taken)}}
\hadithdefcmd{ibnmajah}{2852}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، عَنْ سُفْيَانَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ الْحَارِثِ الزُّرَقِيِّ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ مَكْحُولٍ، عَنْ أَبِي سَلاَّمٍ الأَعْرَجِ، عَنْ أَبِي أُمَامَةَ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَفَّلَ فِي الْبَدْأَةِ الرُّبُعَ وَفِي الرَّجْعَةِ الثُّلُثَ ‏.‏\hadithno{2852}\hadithgrade{Al-Albani: Daif Isnaad; Muhammad Fouad Abd al-Baqi: Daif Isnaad; Shuaib Al Arnaut: Daif; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from ‘Ubadah bin Samit that the Prophet (ﷺ) awarded one quarter of the spoils to those who attacked the enemy at the beginning and one third to those who attacked at the end}}
\hadithdefcmd{ibnmajah}{2853}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو الْحُسَيْنِ، أَنْبَأَنَا رَجَاءُ بْنُ أَبِي سَلَمَةَ، حَدَّثَنَا عَمْرُو بْنُ شُعَيْبٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ، قَالَ لاَ نَفَلَ بَعْدَ رَسُولِ اللَّهِ صلى الله عليه وسلم يَرُدُّ الْمُسْلِمُونَ قَوِيُّهُمْ عَلَى ضَعِيفِهِمْ ‏.‏ قَالَ رَجَاءٌ فَسَمِعْتُ سُلَيْمَانَ بْنَ مُوسَى، يَقُولُ لَهُ حَدَّثَنِي مَكْحُولٌ، عَنْ حَبِيبِ بْنِ مَسْلَمَةَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم نَفَّلَ فِي الْبَدْأَةِ الرُّبُعَ وَحِينَ قَفَلَ الثُّلُثَ ‏.‏ فَقَالَ عَمْرٌو أُحَدِّثُكَ عَنْ أَبِي عَنْ جَدِّي وَتُحَدِّثُنِي عَنْ مَكْحُولٍ\hadithno{2853}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{‘Amr bin Shu’aib narrated from his father that his grandfather said:“There is no awarding of the spoils after the Messenger of Allah (ﷺ), rather whatever the army acquires (of spoils of war) will be distributed among strong and weak alike.”}}
\hadithdefcmd{ibnmajah}{2854}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ النَّبِيَّ صلى الله عليه وسلم أَسْهَمَ يَوْمَ خَيْبَرَ لِلْفَارِسِ ثَلاَثَةَ أَسْهُمٍ لِلْفَرَسِ سَهْمَانِ وَلِلرَّجُلِ سَهْمٌ ‏.‏\hadithno{2854}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{It was narrated from Ibn ‘Umar that the Prophet (ﷺ) distributed the war spoils on the Day of Khaibar, giving three shares to the horseman, two shares for the horse, and one share for the man}}
\hadithdefcmd{ibnmajah}{2855}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا هِشَامُ بْنُ سَعْدٍ، عَنْ مُحَمَّدِ بْنِ زَيْدِ بْنِ مُهَاجِرِ بْنِ قُنْفُذٍ، قَالَ سَمِعْتُ عُمَيْرًا، مَوْلَى آبِي اللَّحْمِ - قَالَ وَكِيعٌ كَانَ لاَ يَأْكُلُ اللَّحْمَ - قَالَ غَزَوْتُ مَعَ مَوْلاَىَ يَوْمَ خَيْبَرَ وَأَنَا مَمْلُوكٌ فَلَمْ يَقْسِمْ لِي مِنَ الْغَنِيمَةِ وَأُعْطِيتُ مِنْ خُرْثِيِّ الْمَتَاعِ سَيْفًا فَكُنْتُ أَجُرُّهُ إِذَا تَقَلَّدْتُهُ ‏.‏\hadithno{2855}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Sahih}\hadithtrans{‘Umair, the freed slave of Aabi Lahm – Waki’ said; - “He used to not eat meat” – said:“I fought alongside my master on the Day of Khaibar, and I was a slave. I was not given anything from the spoils of war but I was given from the least of the utensils (goods) a sword, which I dragged when I put it around my waist.”}}
\hadithdefcmd{ibnmajah}{2856}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ الرَّحِيمِ بْنُ سُلَيْمَانَ، عَنْ هِشَامٍ، عَنْ حَفْصَةَ بِنْتِ سِيرِينَ، عَنْ أُمِّ عَطِيَّةَ الأَنْصَارِيَّةِ، قَالَتْ غَزَوْتُ مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم سَبْعَ غَزَوَاتٍ أَخْلُفُهُمْ فِي رِحَالِهِمْ وَأَصْنَعُ لَهُمُ الطَّعَامَ وَأُدَاوِي الْجَرْحَى وَأَقُومُ عَلَى الْمَرْضَى ‏.‏\hadithno{2856}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Umm ‘Atiyyah Al-Ansariyyah said:“I fought alongside the Messenger of Allah (ﷺ) in seven campaigns, looking after their goods, making food for them, tending the wounded and looking after the sick.”}}
\hadithdefcmd{ibnmajah}{2857}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا أَبُو أُسَامَةَ، حَدَّثَنِي عَطِيَّةُ بْنُ الْحَارِثِ أَبُو رَوْقٍ الْهَمْدَانِيُّ، حَدَّثَنِي أَبُو الْغَرِيفِ، عُبَيْدُ اللَّهِ بْنُ خَلِيفَةَ عَنْ صَفْوَانَ بْنِ عَسَّالٍ، قَالَ بَعَثَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي سَرِيَّةٍ فَقَالَ ‏ "‏ سِيرُوا بِاسْمِ اللَّهِ وَفِي سَبِيلِ اللَّهِ قَاتِلُوا مَنْ كَفَرَ بِاللَّهِ وَلاَ تُمَثِّلُوا وَلاَ تَغْدِرُوا وَلاَ تَغُلُّوا وَلاَ تَقْتُلُوا وَلِيدًا ‏"‏ ‏.‏\hadithno{2857}\hadithgrade{Al-Albani: Hasan Sahih; Muhammad Fouad Abd al-Baqi: Hasan Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that Safwan bin ‘Assil said:“The Messenger of Allah (ﷺ) sent us in a military detachment and said: ‘Go in the Name of Allah, and in the cause of Allah. Fight those who disbelieve in Allah. Do not mutilate, do not be treacherous, do not steal from the spoils of war, and do not kill children.’”}}
\hadithdefcmd{ibnmajah}{2858}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى، حَدَّثَنَا مُحَمَّدُ بْنُ يُوسُفَ الْفِرْيَابِيُّ، حَدَّثَنَا سُفْيَانُ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنِ ابْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَمَّرَ رَجُلاً عَلَى سَرِيَّةٍ أَوْصَاهُ فِي خَاصَّةِ نَفْسِهِ بِتَقْوَى اللَّهِ وَمَنْ مَعَهُ مِنَ الْمُسْلِمِينَ خَيْرًا فَقَالَ ‏ "‏ اغْزُوا بِاسْمِ اللَّهِ وَفِي سَبِيلِ اللَّهِ قَاتِلُوا مَنْ كَفَرَ بِاللَّهِ اغْزُوا وَلاَ تَغْدِرُوا وَلاَ تَغُلُّوا وَلاَ تُمَثِّلُوا وَلاَ تَقْتُلُوا وَلِيدًا وَإِذَا أَنْتَ لَقِيتَ عَدُوَّكَ مِنَ الْمُشْرِكِينَ فَادْعُهُمْ إِلَى إِحْدَى ثَلاَثِ خِلاَلٍ أَوْ خِصَالٍ فَأَيَّتُهُنَّ أَجَابُوكَ إِلَيْهَا فَاقْبَلْ مِنْهُمْ وَكُفَّ عَنْهُمْ ادْعُهُمْ إِلَى الإِسْلاَمِ فَإِنْ أَجَابُوكَ فَاقْبَلْ مِنْهُمْ وَكُفَّ عَنْهُمْ ثُمَّ ادْعُهُمْ إِلَى التَّحَوُّلِ مِنْ دَارِهِمْ إِلَى دَارِ الْمُهَاجِرِينَ وَأَخْبِرْهُمْ إِنْ هُمْ فَعَلُوا ذَلِكَ أَنَّ لَهُمْ مَا لِلْمُهَاجِرِينَ وَأَنَّ عَلَيْهِمْ مَا عَلَى الْمُهَاجِرِينَ وَإِنْ أَبَوْا فَأَخْبِرْهُمْ أَنَّهُمْ يَكُونُونَ كَأَعْرَابِ الْمُسْلِمِينَ يَجْرِي عَلَيْهِمْ حُكْمُ اللَّهِ الَّذِي يَجْرِي عَلَى الْمُؤْمِنِينَ وَلاَ يَكُونُ لَهُمْ فِي الْفَىْءِ وَالْغَنِيمَةِ شَىْءٌ إِلاَّ أَنْ يُجَاهِدُوا مَعَ الْمُسْلِمِينَ فَإِنْ هُمْ أَبَوْا أَنْ يَدْخُلُوا فِي الإِسْلاَمِ فَسَلْهُمْ إِعْطَاءَ الْجِزْيَةِ فَإِنْ فَعَلُوا فَاقْبَلْ مِنْهُمْ وَكُفَّ عَنْهُمْ فَإِنْ هُمْ أَبَوْا فَاسْتَعِنْ بِاللَّهِ عَلَيْهِمْ وَقَاتِلْهُمْ وَإِنْ حَاصَرْتَ حِصْنًا فَأَرَادُوكَ أَنْ تَجْعَلَ لَهُمْ ذِمَّةَ اللَّهِ وَذِمَّةَ نَبِيِّكَ فَلاَ تَجْعَلْ لَهُمْ ذِمَّةَ اللَّهِ وَلاَ ذِمَّةَ نَبِيِّكَ وَلَكِنِ اجْعَلْ لَهُمْ ذِمَّتَكَ وَذِمَّةَ أَبِيكَ وَذِمَّةَ أَصْحَابِكَ فَإِنَّكُمْ إِنْ تُخْفِرُوا ذِمَّتَكُمْ وَذِمَّةَ آبَائِكُمْ أَهْوَنُ عَلَيْكُمْ مِنْ أَنْ تُخْفِرُوا ذِمَّةَ اللَّهِ وَذِمَّةَ رَسُولِهِ وَإِنْ حَاصَرْتَ حِصْنًا فَأَرَادُوكَ أَنْ يَنْزِلُوا عَلَى حُكْمِ اللَّهِ فَلاَ تُنْزِلْهُمْ عَلَى حُكْمِ اللَّهِ وَلَكِنْ أَنْزِلْهُمْ عَلَى حُكْمِكَ فَإِنَّكَ لاَ تَدْرِي أَتُصِيبُ فِيهِمْ حُكْمَ اللَّهِ أَمْ لاَ ‏"‏ ‏.‏ قَالَ عَلْقَمَةُ فَحَدَّثْتُ بِهِ، مُقَاتِلَ بْنَ حَيَّانَ فَقَالَ حَدَّثَنِي مُسْلِمُ بْنُ هَيْصَمٍ، عَنِ النُّعْمَانِ بْنِ مُقَرِّنٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم مِثْلَ ذَلِكَ ‏.‏\hadithno{2858}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn Buraidah that his father said:“Whenever he appointed a man to lead a military detachment, the Messenger of Allah (ﷺ) would advise him especially to fear Allah and treat the Muslims with him well. He (ﷺ) said: ‘Fight in the Name of Allah and in the cause of Allah. Fight those how disbelieve in Allah. Fight but do not be treacherous, do not steal from the spoils of war, do not mutilate and do not kill children. When you meet your enemy from among the polytheists, call them to one of three things. Whichever of them they respond to, accept it from them and refrain from fighting them. Invite them to accept Islam, and if they respond then accept it from them and refrain from fighting them. Then invite them to leave their land and move to the land of the polytheists. Tell them that if they do that, then they will have the same rights and duties as the polytheists. If they refuse, then tell them that they will be like the Muslim Bedouins (who live in the desert), subject to the same rulings of Allah as the believers. But they will have no share of Fay’* or war spoils, unless they fight alongside the Muslims. If they refuse to enter Islam, then ask them to pay the Poll-tax. If they do that, then accept it from them and refrain from fighting them. But if they refuse, then seek the help of Allah against them and fight them. If you lay siege to them and they want you to give them the protection of Allah and your Prophet, do not give them the protection of Allah and your Prophet, rather give them your protection and the protection of your father and your Companions, for if you violate your protection and the protection of your fathers, that is easier than violating the protection of Allah and the protection of His Messenger. If you lay siege to them and they want you to let them come out with a promise of the judgement of Allah and His Messenger (ﷺ), do not offer them a promise of the judgement of Allah and His Messenger (ﷺ), rather offer them your judgement, because you do not know if you will actually pass (the same as) Allah’s judgement regarding them or not.’” Another chain reports a similar hadith}}
\hadithdefcmd{ibnmajah}{2859}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، قَالاَ حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا الأَعْمَشُ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَطَاعَنِي فَقَدْ أَطَاعَ اللَّهَ وَمَنْ عَصَانِي فَقَدْ عَصَى اللَّهَ وَمَنْ أَطَاعَ الإِمَامَ فَقَدْ أَطَاعَنِي وَمَنْ عَصَى الإِمَامَ فَقَدْ عَصَانِي ‏"‏ ‏.‏\hadithno{2859}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever obeys me, obeys Allah, And whoever disobeys me, disobeys Allah. Whoever obeys the ruler, obeys me, and whoever disobeys the ruler, disobeys me.”}}
\hadithdefcmd{ibnmajah}{2860}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَأَبُو بِشْرٍ بَكْرُ بْنُ خَلَفٍ قَالاَ حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا شُعْبَةُ، حَدَّثَنِي أَبُو التَّيَّاحِ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ اسْمَعُوا وَأَطِيعُوا وَإِنِ اسْتُعْمِلَ عَلَيْكُمْ عَبْدٌ حَبَشِيٌّ كَأَنَّ رَأْسَهُ زَبِيبَةٌ ‏"‏ ‏.‏\hadithno{2860}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Anas bin Malik that the Messenger of Allah (ﷺ) said:“Listen and obey, even if the one appointed over you is an Ethiopian slave with a head like a raisin.”}}
\hadithdefcmd{ibnmajah}{2861}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا وَكِيعُ بْنُ الْجَرَّاحِ، عَنْ شُعْبَةَ، عَنْ يَحْيَى بْنِ الْحُصَيْنِ، عَنْ جَدَّتِهِ أُمِّ الْحُصَيْنِ، قَالَتْ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ إِنْ أُمِّرَ عَلَيْكُمْ عَبْدٌ حَبَشِيٌّ مُجَدَّعٌ فَاسْمَعُوا لَهُ وَأَطِيعُوا مَا قَادَكُمْ بِكِتَابِ اللَّهِ ‏"‏ ‏.‏\hadithno{2861}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Umm Husain that she heard the Messenger of Allah (ﷺ) say:“Even if the one appointed over you is a mutilated Ethiopian slave whose nose and ears have been cut off, listen to him and obey, so long as he leads you according to the Book of Allah.”}}
\hadithdefcmd{ibnmajah}{2862}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ عَبْدِ اللَّهِ بْنِ الصَّامِتِ، عَنْ أَبِي ذَرٍّ، أَنَّهُ انْتَهَى إِلَى الرَّبَذَةِ وَقَدْ أُقِيمَتِ الصَّلاَةُ فَإِذَا عَبْدٌ يَؤُمُّهُمْ فَقِيلَ هَذَا أَبُو ذَرٍّ ‏.‏ فَذَهَبَ يَتَأَخَّرُ فَقَالَ أَبُو ذَرٍّ أَوْصَانِي خَلِيلِي صلى الله عليه وسلم أَنْ أَسْمَعَ وَأُطِيعَ وَإِنْ كَانَ عَبْدًا حَبَشِيًّا مُجَدَّعَ الأَطْرَافِ ‏.‏\hadithno{2862}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Dharr that he reached Rabadhah when the Iqamah for the prayer had already been given, and there was a slave leading them in prayer. It was said:“This is Abu Dharr,” so he (the slave) started to move back. But Abu Dharr said: “My close friend (i.e., the Prophet (ﷺ)) told me to listen and obey, even if (the leader was) an Ethiopian slave with amputated limbs.”}}
\hadithdefcmd{ibnmajah}{2863}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، حَدَّثَنَا مُحَمَّدُ بْنُ عَمْرٍو، عَنْ عُمَرَ بْنِ الْحَكَمِ بْنِ ثَوْبَانَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم بَعَثَ عَلْقَمَةَ بْنَ مُجَزِّزٍ عَلَى بَعْثٍ وَأَنَا فِيهِمْ فَلَمَّا انْتَهَى إِلَى رَأْسِ غَزَاتِهِ أَوْ كَانَ بِبَعْضِ الطَّرِيقِ اسْتَأْذَنَتْهُ طَائِفَةٌ مِنَ الْجَيْشِ فَأَذِنَ لَهُمْ وَأَمَّرَ عَلَيْهِمْ عَبْدَ اللَّهِ بْنَ حُذَافَةَ بْنِ قَيْسٍ السَّهْمِيَّ فَكُنْتُ فِيمَنْ غَزَا مَعَهُ فَلَمَّا كَانَ بِبَعْضِ الطَّرِيقِ أَوْقَدَ الْقَوْمُ نَارًا لِيَصْطَلُوا أَوْ لِيَصْنَعُوا عَلَيْهَا صَنِيعًا فَقَالَ عَبْدُ اللَّهِ - وَكَانَتْ فِيهِ دُعَابَةٌ - أَلَيْسَ لِي عَلَيْكُمُ السَّمْعُ وَالطَّاعَةُ قَالُوا بَلَى ‏.‏ قَالَ فَمَا أَنَا بِآمِرِكُمْ بِشَىْءٍ إِلاَّ صَنَعْتُمُوهُ قَالُوا نَعَمْ ‏.‏ قَالَ فَإِنِّي أَعْزِمُ عَلَيْكُمْ إِلاَّ تَوَاثَبْتُمْ فِي هَذِهِ النَّارِ ‏.‏ فَقَامَ نَاسٌ فَتَحَجَّزُوا فَلَمَّا ظَنَّ أَنَّهُمْ وَاثِبُونَ قَالَ أَمْسِكُوا عَلَى أَنْفُسِكُمْ فَإِنَّمَا كُنْتُ أَمْزَحُ مَعَكُمْ ‏.‏ فَلَمَّا قَدِمْنَا ذَكَرُوا ذَلِكَ لِلنَّبِيِّ صلى الله عليه وسلم فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَمَرَكُمْ مِنْهُمْ بِمَعْصِيَةِ اللَّهِ فَلاَ تُطِيعُوهُ ‏"‏ ‏.‏\hadithno{2863}\hadithgrade{Al-Albani: Hasan; Muhammad Fouad Abd al-Baqi: Hasan; Shuaib Al Arnaut: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Messenger of Allah (ﷺ) sent ‘Alqamah bin Mujazziz at the head of a detachment, and I was among them. When he reached the battle site, or when he was partway there, a group of the army asked permission to take a different route, and he gave them permission, and appointed ‘Abdullah bin Hudhafah bin Qais As-Sahmi as their leader, and I was one of those who fought alongside with him. When we were partway there, the people lit a fire to warm themselves and cook some food. ‘Abdullah, who was a man who liked to joke, said:“Do I not have the right that you should listen to me and obey?” They said: “Yes.” He said: “And if I command you to do something, will you not do it?” They said: “Of course.” He said: “Then I command you to jump into this fire.” Some people got up and got ready to jump, and when he saw that they were about to jump, he said: “Restrain yourselves, for I was joking with you.” When we came to Al-Madinah, they mentioned that to the Prophet (ﷺ), and the Messenger of Allah (ﷺ) said: “Whoever among you commands you to do something that involves disobedience to Allah, do not obey him.”}}
\hadithdefcmd{ibnmajah}{2864}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ عُبَيْدِ اللَّهِ بْنِ عُمَرَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ الصَّبَّاحِ، وَسُوَيْدُ بْنُ سَعِيدٍ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ رَجَاءٍ الْمَكِّيُّ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عَلَى الْمَرْءِ الْمُسْلِمِ الطَّاعَةُ فِيمَا أَحَبَّ أَوْ كَرِهَ إِلاَّ أَنْ يُؤْمَرَ بِمَعْصِيَةٍ فَمَنْ أُمِرَ بِمَعْصِيَةٍ فَلاَ سَمْعَ وَلاَ طَاعَةَ ‏"‏ ‏.‏\hadithno{2864}\hadithgrade{Al-Albani: Sahih Isnaad; Muhammad Fouad Abd al-Baqi: Sahih Isnaad; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) said:“The Muslim is obliged to obey (the ruler) whether he likes it or not, unless he is commanded to commit an act of disobedience. If he is commanded to commit a sin then he should neither listen nor obey.”}}
\hadithdefcmd{ibnmajah}{2865}{حَدَّثَنَا سُوَيْدُ بْنُ سَعِيدٍ، حَدَّثَنَا يَحْيَى بْنُ سُلَيْمٍ، ح وَحَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ عَيَّاشٍ، قَالاَ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ خُثَيْمٍ، عَنِ الْقَاسِمِ بْنِ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، عَنْ أَبِيهِ، عَنْ جَدِّهِ عَبْدِ اللَّهِ بْنِ مَسْعُودٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏"‏ سَيَلِي أُمُورَكُمْ بَعْدِي رِجَالٌ يُطْفِئُونَ السُّنَّةَ وَيَعْمَلُونَ بِالْبِدْعَةِ وَيُؤَخِّرُونَ الصَّلاَةَ عَنْ مَوَاقِيتِهَا ‏"‏ فَقُلْتُ يَا رَسُولَ اللَّهِ إِنْ أَدْرَكْتُهُمْ كَيْفَ أَفْعَلُ قَالَ ‏"‏ تَسْأَلُنِي يَا ابْنَ أُمِّ عَبْدٍ كَيْفَ تَفْعَلُ لاَ طَاعَةَ لِمَنْ عَصَى اللَّهَ ‏"‏ ‏.‏\hadithno{2865}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated from ‘Abdullah bin Mas’ud that the Prophet (ﷺ) said:“Among those in charge of you, after I am gone, will be men who extinguish the Sunnah and follow innovation. They will delay the prayer from its proper time.” I said: “O Messenger of Allah, if I live to see them, what should I do?” He said: “You ask me, O Ibn ‘Abd, what you should do? There is no obedience to one who disobeys Allah.”}}
\hadithdefcmd{ibnmajah}{2866}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، وَيَحْيَى بْنِ سَعِيدٍ، وَعُبَيْدِ اللَّهِ بْنِ عُمَرَ، وَابْنِ، عَجْلاَنَ عَنْ عُبَادَةَ بْنِ الْوَلِيدِ بْنِ عُبَادَةَ بْنِ الصَّامِتِ، عَنْ أَبِيهِ، عَنْ عُبَادَةَ بْنِ الصَّامِتِ، قَالَ بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ فِي الْعُسْرِ وَالْيُسْرِ وَالْمَنْشَطِ وَالْمَكْرَهِ وَالأَثَرَةِ عَلَيْنَا وَأَنْ لاَ نُنَازِعَ الأَمْرَ أَهْلَهُ وَأَنْ نَقُولَ الْحَقَّ حَيْثُمَا كُنَّا لاَ نَخَافُ فِي اللَّهِ لَوْمَةَ لاَئِمٍ ‏.‏\hadithno{2866}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated that ‘Ubadah bin Samit said:“We gave our pledge to the Messenger of Allah (ﷺ), pledging to listen and obey in times of hardship and times of ease, willingly or reluctantly, and when others are shown preference over us, and that we would not dispute the order of those in charge, that we would speak the truth wherever we are, and that we would not fear the blame of anyone when acting or speaking for the sake of Allah.”}}
\hadithdefcmd{ibnmajah}{2867}{حَدَّثَنَا هِشَامُ بْنُ عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الْعَزِيزِ التَّنُوخِيُّ، عَنْ رَبِيعَةَ بْنِ يَزِيدَ، عَنْ أَبِي إِدْرِيسَ الْخَوْلاَنِيِّ، عَنْ أَبِي مُسْلِمٍ، قَالَ حَدَّثَنِي الْحَبِيبُ الأَمِينُ، - أَمَّا هُوَ إِلَىَّ فَحَبِيبٌ وَأَمَّا هُوَ عِنْدِي فَأَمِينٌ - عَوْفُ بْنُ مَالِكٍ الأَشْجَعِيُّ قَالَ كُنَّا عِنْدَ النَّبِيِّ صلى الله عليه وسلم سَبْعَةً أَوْ ثَمَانِيَةً أَوْ تِسْعَةً فَقَالَ ‏"‏ أَلاَ تُبَايِعُونَ رَسُولَ اللَّهِ ‏"‏ ‏.‏ فَبَسَطْنَا أَيْدِيَنَا فَقَالَ قَائِلٌ يَا رَسُولَ اللَّهِ إِنَّا قَدْ بَايَعْنَاكَ فَعَلاَمَ نُبَايِعُكَ فَقَالَ ‏"‏ أَنْ تَعْبُدُوا اللَّهَ وَلاَ تُشْرِكُوا بِهِ شَيْئًا وَتُقِيمُوا الصَّلَوَاتِ الْخَمْسَ وَتَسْمَعُوا وَتُطِيعُوا - وَأَسَرَّ كَلِمَةً خُفْيَةً - وَلاَ تَسْأَلُوا النَّاسَ شَيْئًا ‏"‏ ‏.‏ قَالَ فَلَقَدْ رَأَيْتُ بَعْضَ أُولَئِكَ النَّفَرِ يَسْقُطُ سَوْطُهُ فَلاَ يَسْأَلُ أَحَدًا يُنَاوِلُهُ إِيَّاهُ ‏.‏\hadithno{2867}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{‘Awf bin Malik Al-Ashja’i said:“We were with the Prophet (ﷺ) – seven or eight or nine of us – and he said: ‘Will you not give pledge to the Messenger of Allah?’ So we stretched forth our hands and someone said: ‘O Messenger of Allah, we have already given you our pledge. On what basis shall we give this pledge?’ He said: ‘(On the basis that) you will worship Allah and not associate anything with Him, you will establish the five daily prayers, you will listen and obey’ – then he spoke some words under his breath – ‘and you will not ask the people for anything.’ He said: ‘I saw some of that group. If he dropped his whip he would not ask anyone to pick it up for him.’”}}
\hadithdefcmd{ibnmajah}{2868}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا شُعْبَةُ، عَنْ عَتَّابٍ، - مَوْلَى هُرْمُزَ - قَالَ سَمِعْتُ أَنَسَ بْنَ مَالِكٍ، يَقُولُ بَايَعْنَا رَسُولَ اللَّهِ صلى الله عليه وسلم عَلَى السَّمْعِ وَالطَّاعَةِ فَقَالَ ‏ "‏ فِيمَا اسْتَطَعْتُمْ ‏"‏ ‏.‏\hadithno{2868}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih Lighairihi; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{It was narrated that ‘Attab, the freed slave of Hurmuz, said:“I heard Anas bin Malik say: ‘We gave our pledge to the Messenger of Allah (ﷺ) on the basis that we would listen and obey. He (ﷺ) said: “As much as you can.”}}
\hadithdefcmd{ibnmajah}{2869}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ جَاءَ عَبْدٌ فَبَايَعَ النَّبِيَّ صلى الله عليه وسلم عَلَى الْهِجْرَةِ وَلَمْ يَشْعُرِ النَّبِيُّ صلى الله عليه وسلم أَنَّهُ عَبْدٌ فَجَاءَ سَيِّدُهُ يُرِيدُهُ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏ "‏ بِعْنِيهِ ‏"‏ ‏.‏ فَاشْتَرَاهُ بِعَبْدَيْنِ أَسْوَدَيْنِ ثُمَّ لَمْ يُبَايِعْ أَحَدًا بَعْدَ ذَلِكَ حَتَّى يَسْأَلَهُ أَعَبْدٌ هُوَ\hadithno{2869}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Jabir said:“A slave came and gave his pledge to the Prophet (ﷺ), pledging to emigrate, and the Prophet (ﷺ) did not realize that he was a slave. Then his master came looking for him, and the Prophet (ﷺ) said: ‘Sell him to me,’ and he brought him in exchange for two black slaves. Then after that he did not accept the pledge from anyone until he had asked whether he was a slave.”}}
\hadithdefcmd{ibnmajah}{2870}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَعَلِيُّ بْنُ مُحَمَّدٍ، وَأَحْمَدُ بْنُ سِنَانٍ، قَالُوا حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ لاَ يُكَلِّمُهُمُ اللَّهُ وَلاَ يَنْظُرُ إِلَيْهِمْ يَوْمَ الْقِيَامَةِ وَلاَ يُزَكِّيهِمْ وَلَهُمْ عَذَابٌ أَلِيمٌ رَجُلٌ عَلَى فَضْلِ مَاءٍ بِالْفَلاَةِ يَمْنَعُهُ مِنِ ابْنِ السَّبِيلِ وَرَجُلٌ بَايَعَ رَجُلاً بِسِلْعَةٍ بَعْدَ الْعَصْرِ فَحَلَفَ بِاللَّهِ لأَخَذَهَا بِكَذَا وَكَذَا فَصَدَّقَهُ وَهُوَ عَلَى غَيْرِ ذَلِكَ وَرَجُلٌ بَايَعَ إِمَامًا لاَ يُبَايِعُهُ إِلاَّ لِدُنْيَا فَإِنْ أَعْطَاهُ مِنْهَا وَفَى لَهُ وَإِنْ لَمْ يُعْطِهِ مِنْهَا لَمْ يَفِ لَهُ ‏"‏ ‏.‏\hadithno{2870}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“There are three to whom Allah will not speak on the Day of Resurrection, not will He look at them nor purify them, and theirs will be a painful torment: A man who has surplus water in the desert and withholds it from a wayfarer; a man who sells a man his product after ‘Asr, swearing by Allah that he bought it for such and such a price, and the other believes him, but that is not the case; and a man who gives his pledge to a ruler, only doing to for the purpose of worldly gain, and if he is given something he fulfills it, but if he is not given anything he does not fulfill it.”}}
\hadithdefcmd{ibnmajah}{2871}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ إِدْرِيسَ، عَنْ حَسَنِ بْنِ فُرَاتٍ، عَنْ أَبِيهِ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ إِنَّ بَنِي إِسْرَائِيلَ كَانَتْ تَسُوسُهُمْ أَنْبِيَاؤُهُمْ كُلَّمَا ذَهَبَ نَبِيٌّ خَلَفَهُ نَبِيٌّ وَأَنَّهُ لَيْسَ كَائِنٌ بَعْدِي نَبِيٌّ فِيكُمْ ‏"‏ ‏.‏ قَالُوا فَمَا يَكُونُ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ تَكُونُ خُلَفَاءُ فَيَكْثُرُوا ‏"‏ ‏.‏ قَالُوا فَكَيْفَ نَصْنَعُ قَالَ ‏"‏ أَوْفُوا بِبَيْعَةِ الأَوَّلِ فَالأَوَّلِ أَدُّوا الَّذِي عَلَيْكُمْ فَسَيَسْأَلُهُمُ اللَّهُ عَزَّ وَجَلَّ عَنِ الَّذِي عَلَيْهِمْ ‏"‏ ‏.‏\hadithno{2871}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“The affairs of the Children of Israel were administered by their Prophets. Every time a Prophet left, he was followed by another, but there will be no Prophet among you after I am gone.” They said: “What will happen, O Messenger of Allah?” He said: “There will be caliphs and there will be many of them.” They said: “What should we do?” He said: “Fulfill your pledge to the first one, then the one who comes after him, and do the duties required of you, for Allah will question them about the duties upon them.”}}
\hadithdefcmd{ibnmajah}{2872}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ نُمَيْرٍ، حَدَّثَنَا أَبُو الْوَلِيدِ، حَدَّثَنَا شُعْبَةُ، ح وَحَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا ابْنُ أَبِي عَدِيٍّ، عَنْ شُعْبَةَ، عَنِ الأَعْمَشِ، عَنْ أَبِي وَائِلٍ، عَنْ عَبْدِ اللَّهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ يُنْصَبُ لِكُلِّ غَادِرٍ لِوَاءٌ يَوْمَ الْقِيَامَةِ فَيُقَالُ هَذِهِ غَدْرَةُ فُلاَنٍ ‏"‏ ‏.‏\hadithno{2872}\hadithgrade{Al-Albani: Sahih Mutawatir; Muhammad Fouad Abd al-Baqi: Sahih Mutawatir; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from ‘Abdullah that the Messenger of Allah (ﷺ) said:“A banner will be set up for every traitor on the Day of Resurrection, and it will be said: ‘This is the treachery of so-and- so.’”}}
\hadithdefcmd{ibnmajah}{2873}{حَدَّثَنَا عِمْرَانُ بْنُ مُوسَى اللَّيْثِيُّ، حَدَّثَنَا حَمَّادُ بْنُ زَيْدٍ، أَنْبَأَنَا عَلِيُّ بْنُ زَيْدِ بْنِ جُدْعَانَ، عَنْ أَبِي نَضْرَةَ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَلاَ إِنَّهُ يُنْصَبُ لِكُلِّ غَادِرٍ لِوَاءٌ يَوْمَ الْقِيَامَةِ بِقَدْرِ غَدْرَتِهِ ‏"‏ ‏.‏\hadithno{2873}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Sa’eed Al-Khudri that the Messenger of Allah (ﷺ) said:“For every traitor a banner will be set up on the Day of Resurrection, commensurate with his treachery.”}}
\hadithdefcmd{ibnmajah}{2874}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، أَنَّهُ سَمِعَ مُحَمَّدَ بْنَ الْمُنْكَدِرِ، قَالَ سَمِعْتُ أُمَيْمَةَ بِنْتَ رُقَيْقَةَ، تَقُولُ جِئْتُ النَّبِيَّ صلى الله عليه وسلم فِي نِسْوَةٍ نُبَايِعُهُ فَقَالَ لَنَا ‏ "‏ فِيمَا اسْتَطَعْتُنَّ وَأَطَقْتُنَّ إِنِّي لاَ أُصَافِحُ النِّسَاءَ ‏"‏ ‏.‏\hadithno{2874}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Muhammad bin Munkadir said that he heard Umaimah bint Ruqaiqah say:“I came to the Prophet (ﷺ) with some other women, to offer our pledge to him. He said to us: ‘(I accept your pledge) with regard to what you are able to do. But I do not shake hands with women.’”}}
\hadithdefcmd{ibnmajah}{2875}{حَدَّثَنَا أَحْمَدُ بْنُ عَمْرِو بْنِ السَّرْحِ الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ وَهْبٍ، قَالَ أَخْبَرَنِي يُونُسُ، عَنِ ابْنِ شِهَابٍ، أَخْبَرَنِي عُرْوَةُ بْنُ الزُّبَيْرِ، أَنَّ عَائِشَةَ، زَوْجَ النَّبِيِّ صلى الله عليه وسلم قَالَتْ كَانَتِ الْمُؤْمِنَاتُ إِذَا هَاجَرْنَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يُمْتَحَنَّ بِقَوْلِ اللَّهِ ‏\{يَا أَيُّهَا النَّبِيُّ إِذَا جَاءَكَ الْمُؤْمِنَاتُ يُبَايِعْنَكَ \}‏ إِلَى آخِرِ الآيَةِ قَالَتْ عَائِشَةُ فَمَنْ أَقَرَّ بِهَا مِنَ الْمُؤْمِنَاتِ فَقَدْ أَقَرَّ بِالْمِحْنَةِ فَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم إِذَا أَقْرَرْنَ بِذَلِكَ مِنْ قَوْلِهِنَّ قَالَ لَهُنَّ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ انْطَلِقْنَ فَقَدْ بَايَعْتُكُنَّ ‏"‏ ‏.‏ لاَ وَاللَّهِ مَا مَسَّتْ يَدُ رَسُولِ اللَّهِ صلى الله عليه وسلم يَدَ امْرَأَةٍ قَطُّ غَيْرَ أَنَّهُ يُبَايِعُهُنَّ بِالْكَلاَمِ ‏.‏ قَالَتْ عَائِشَةُ وَاللَّهِ مَا أَخَذَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَلَى النِّسَاءِ إِلاَّ مَا أَمَرَهُ اللَّهُ وَلاَ مَسَّتْ كَفُّ رَسُولِ اللَّهِ صلى الله عليه وسلم كَفَّ امْرَأَةٍ قَطُّ وَكَانَ يَقُولُ لَهُنَّ إِذَا أَخَذَ عَلَيْهِنَّ ‏"‏ قَدْ بَايَعْتُكُنَّ ‏"‏ ‏.‏ كَلاَمًا ‏.‏\hadithno{2875}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{‘Aishah the wife of the Prophet (ﷺ) said:“When the believing women emigrated to the Messenger of Allah (ﷺ), they would be tested in accordance with Allah’s saying: ‘O Prophet! When believing women come to you to give you the pledge...’”[60:12] ‘Aishah said: “Whoever among the believing women affirmed this, passed the test. When they affirmed that, the Messenger of Allah (ﷺ) would say to them: ‘Go, for you have given your pledge.’ No, by Allah! The hand of the Messenger of Allah (ﷺ) never touched the hand of any woman, rather he accepted their pledge in words only.” ‘Aishah said: “By Allah, the Messenger of Allah (ﷺ) did not demand of women (in their pledge) anything other than that which Allah had commanded, and the hand of the Messenger of Allah (ﷺ) never touched the hand of a woman. He would say to them, when he had accepted their pledge: ‘You have given your pledge,’ verbally.”}}
\hadithdefcmd{ibnmajah}{2876}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، وَمُحَمَّدُ بْنُ يَحْيَى، قَالاَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا سُفْيَانُ بْنُ حُسَيْنٍ، عَنِ الزُّهْرِيِّ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَدْخَلَ فَرَسًا بَيْنَ فَرَسَيْنِ وَهُوَ لاَ يَأْمَنُ أَنْ يَسْبِقَ فَلَيْسَ بِقِمَارٍ وَمَنْ أَدْخَلَ فَرَسًا بَيْنَ فَرَسَيْنِ وَهُوَ يَأْمَنُ أَنْ يَسْبِقَ فَهُوَ قِمَارٌ ‏"‏ ‏.‏\hadithno{2876}\hadithgrade{Al-Albani: Daif; Muhammad Fouad Abd al-Baqi: Daif; Zubair Ali Zai: Daif}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“Whoever enters a horse (in a race) between two other horses, not knowing whether it will win, that is not gambling. But whoever enters a horse (in race) between two other horses, certain that it will win, that is gambling.”}}
\hadithdefcmd{ibnmajah}{2877}{حَدَّثَنَا عَلِيُّ بْنُ مُحَمَّدٍ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نُمَيْرٍ، عَنْ عُبَيْدِ اللَّهِ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ ضَمَّرَ رَسُولُ اللَّهِ صلى الله عليه وسلم الْخَيْلَ فَكَانَ يُرْسِلُ الَّتِي ضُمِّرَتْ مِنَ الْحَفْيَاءِ إِلَى ثَنِيَّةِ الْوَدَاعِ وَالَّتِي لَمْ تُضَمَّرْ مِنْ ثَنِيَّةِ الْوَدَاعِ إِلَى مَسْجِدِ بَنِي زُرَيْقٍ ‏.‏\hadithno{2877}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated that Ibn ‘Umar said:“The Messenger of Allah (ﷺ) made a horse lean, and he would send the horse that he had made lean from Hafya’ to Thaniyyatul-Wada’, and (he would send) the horse that he had not made lean from Thaniyyatul-Wada’ to the mosque of Banu Zuraiq.”}}
\hadithdefcmd{ibnmajah}{2878}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي شَيْبَةَ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، عَنْ أَبِي الْحَكَمِ، - مَوْلَى بَنِي لَيْثٍ - عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ سَبَقَ إِلاَّ فِي خُفٍّ أَوْ حَافِرٍ ‏"‏ ‏.‏\hadithno{2878}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{It was narrated from Abu Hurairah that the Messenger of Allah (ﷺ) said:“There should be no prizes for racing except races with camels and horses.”}}
\hadithdefcmd{ibnmajah}{2879}{حَدَّثَنَا أَحْمَدُ بْنُ سِنَانٍ، وَأَبُو عُمَرَ قَالاَ حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم نَهَى أَنْ يُسَافَرَ بِالْقُرْآنِ إِلَى أَرْضِ الْعَدُوِّ مَخَافَةَ أَنْ يَنَالَهُ الْعَدُوُّ ‏.‏\hadithno{2879}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) forbade traveling with the Qur’an to the land of the enemy, lest the enemy gets hold of it}}
\hadithdefcmd{ibnmajah}{2880}{حَدَّثَنَا مُحَمَّدُ بْنُ رُمْحٍ، أَنْبَأَنَا اللَّيْثُ بْنُ سَعْدٍ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ كَانَ يَنْهَى أَنْ يُسَافَرَ بِالْقُرْآنِ إِلَى أَرْضِ الْعَدُوِّ مَخَافَةَ أَنْ يَنَالَهُ الْعَدُوُّ ‏.‏\hadithno{2880}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Shuaib Al Arnaut: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{It was narrated from Ibn ‘Umar that the Messenger of Allah (ﷺ) used to forbid traveling with the Qur’an to the land of the enemy, lest the enemy gets hold of it}}
\hadithdefcmd{ibnmajah}{2881}{حَدَّثَنَا يُونُسُ بْنُ عَبْدِ الأَعْلَى، حَدَّثَنَا أَيُّوبُ بْنُ سُوَيْدٍ، عَنْ يُونُسَ بْنِ يَزِيدَ، عَنِ ابْنِ شِهَابٍ، عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، أَنَّ جُبَيْرَ بْنَ مُطْعِمٍ، أَخْبَرَهُ أَنَّهُ، جَاءَ هُوَ وَعُثْمَانُ بْنُ عَفَّانَ إِلَى رَسُولِ اللَّهِ صلى الله عليه وسلم يُكَلِّمَانِهِ فِيمَا قَسَمَ مِنْ خُمُسِ خَيْبَرَ لِبَنِي هَاشِمٍ وَبَنِي الْمُطَّلِبِ فَقَالاَ قَسَمْتَ لإِخْوَانِنَا بَنِي هَاشِمٍ وَبَنِي الْمُطَّلِبِ وَقَرَابَتُنَا وَاحِدَةٌ فَقَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا أَرَى بَنِي هَاشِمٍ وَبَنِي الْمُطَّلِبِ شَيْئًا وَاحِدًا ‏"‏ ‏.‏\hadithno{2881}\hadithgrade{Al-Albani: Sahih; Muhammad Fouad Abd al-Baqi: Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{It was narrated from Sa’eed bin Musayyab that Jubair bin Mut’im told him that he and ‘Uthman bin ‘Affan came to the Messenger of Allah (ﷺ) to speak to him about the way in which the one fifth from Khaibar had been distributed to Banu Hashim and Banu Muttalib. They said:“You have distributed it to our brothers Banu Hashim and Banu Muttalib, but we are related to you (to Banu Hashim) in the same way (as Banu Muttalib).” The Messenger of Allah (ﷺ) said: “Rather I think that Banu Hashim and Banu Muttalib are the same.”}}
